@@ -15,7 +15,7 @@ use Zim::Store;
 use Zim::History;
 use Zim::Page;
 
-our $VERSION = '0.26';
+our $VERSION = '0.29';
 
 our @ISA = qw/Zim::Events/;
 
@@ -35,13 +35,31 @@ Please report bugs to pardus\@cpan.org
 EOT
 our $AUTHORS = 'Jaap Karssenberg <pardus@cpan.org>';
 our $TRANSLATORS = q{
+Akihiro Nishimura (ja)
+Andrew Kuzminov (ru)
 Andrés Rassol (es)
+Aron Xu (zh_CN)
+BBO (de)
 Balaam's Miracle (nl)
+Bart (nl)
+Bjørn Olav Samdal (nb)
+BobMauchin (fr)
+Cheese Lee (zh_CN)
+Daniel Ribeiro (pt_BR)
 Daniel Stoyanov (fr)
+Davide Truffa (it)
 Etienne Le Belléguy (fr)
+Eugene Schava (ru)
+Fabian Affolter (de)
+Federico Vera (es)
+Frederico Gonçalves Guimarães (pt_BR)
 Frederik 'Freso' S. Olesen (da)
 Frits Salomons (nl)
+Gofer (ru)
+Gökdeniz Karadağ (tr)
+Henry Lee (zh_TW)
 Hokey (de)
+István Papp (hu)
 Jaap Karssenberg (nl)
 Jacopo Moronato (it)
 Javier Rovegno Campos (es)
@@ -50,29 +68,56 @@ Jean Demartini (fr)
 Jeppe Toustrup (da)
 João Santos (pt)
 Juhana Uuttu (fi)
+Junnan Wu (zh_CN)
 Jérôme Guelfucci (fr)
+Katz Kawai (ja)
 Klaus Vormweg (de)
+Krzysztof Tataradziński (pl)
+Lucif (pl)
 M. Emin Akşehirli (tr)
 Mathijs (nl)
+Matteo Ferrabone (it)
+Matthew Gadd (en_GB)
 Matthias Mailänder (de)
+Maxim Kochetkov aka fido_max (ru)
+Miguel Anxo Bouzada (gl)
 Mikael Mildén (sv)
 Nikolaus Klumpp (de)
 Nikolay A. Fetisov (ru)
 Nucleos (fr)
+Oleg Maximov (ru)
 Paco Molinero (es)
 René 'Necoro' Neumann (de)
 Roberto Suarez (gl)
 Rui Nibau (fr)
 Servilio Afre Puentes (es)
+ThiagoSerra (pt_BR)
+Tverd (ru)
+Vinzenz Vietzke (de)
 Vladimir Sharshov (ru)
 Vlastimil Ott (cs)
+Vyacheslav Kurenyshev (ru)
+Wanderson Santiago dos Reis (pt_BR)
+X-Ander (ru)
 Yaron (he)
+ZZYZX (pl)
+atany (uk)
+cumulus007 (nl)
+cyberik (zh_TW)
+dotancohen (he)
+forget (zh_CN)
+kingu (nb)
 marisma (gl)
-rainofchaos (zh_CN)
+nairobie (sv)
+nanker (da)
+orz.inc (ja)
+paxatouridis (el)
 sanya (ru)
+warlock24 (pl)
+冯超 (zh_CN)
 太和 (zh_CN)
 };
-our $WEBSITE = 'http://www.pardus.nl/projects/zim';
+our $WEBSITE = 'http://zim-wiki.org/';
 
 =head1 NAME
 
@@ -81,7 +126,7 @@ Zim - Application object for the zim desktop wiki
 =head1 SYNOPSIS
 
 	use Zim;
-	
+
 	my $repo = Zim->new( dir => $dir );
 	my $page = $repo->get_page('Home');
 
@@ -159,6 +204,9 @@ sub new {
 	$$self{config_file} = $self->get_notebook_config;
 	$$self{config_file}->read($$self{config}, 'Notebook')
 		if $$self{config_file};
+	print STDERR "WARNING: FS timestamp checks are disabled\n",
+	             "concurent editing will overwrite files without warning\n"
+		if $$self{config}{no_fs_check} ;
 
 	# Initialize version control
 	$$self{vcs} ||= $class->check_version_control($$self{dir})
@@ -191,10 +239,10 @@ sub new {
 		my $val = $self->{config}{Namespaces}{$ns};
 		my ($class, $arg) = split ',', $val, 2;
 		my %arg = map split('=',$_,2),
-		          map split(',',$_,2), $arg; 
+		          map split(',',$_), $arg;
 		$self->add_child($ns => $class, %arg);
 	}
-	
+
 	return $self;
 }
 
@@ -271,7 +319,7 @@ class L<Zim::History>.
 sub init_history {
 	my $self = shift;
 	return $$self{history} if $$self{history};
-	
+
 	my $cache = $self->get_notebook_cache;
 	my $hist_file = $cache->file('history.cache');
 	my $hist_max = $$self{config}{hist_max} || 15;
@@ -281,7 +329,7 @@ sub init_history {
 	return $$self{history};
 }
 
-=item C<init_vcs(VCS)>
+=item C<init_vcs(VCS, \%ARGS)>
 
 Initializes a Version Control System for the top level notebook dir.
 VCS is the system you want to use, e.g. 'Bazaar'. Only needs to be called
@@ -290,9 +338,9 @@ for notebooks that are not yet under version control.
 =cut
 
 sub init_vcs {
-	my ($self, $vcs) = @_;
+	my ($self, $vcs, $args) = @_;
 	die "BUG: can not initialize VCS without directoy" unless $$self{dir};
-	
+
 	# Expect this eval to die e.g. when the correct VCS is
 	# not installed and can not be used; or e.g. when installed
 	# version has version mis-match etc.
@@ -301,7 +349,7 @@ sub init_vcs {
 	die $@ if $@;
 
 	my $dir = $$self{dir};
-	$vcs = $$self{dir} = $$self{vcs} = $class->init($$self{dir});
+	$vcs = $$self{dir} = $$self{vcs} = $class->init($$self{dir}, $args);
 	$self->_init_properties; # will properly nest doc_root
 
 	for my $child (map $$self{$_}, grep /^:/, keys %$self) {
@@ -379,7 +427,7 @@ sub list_pages {
 	my ($self, $namespace) = @_;
 	$namespace =~ s/:?$/:/;
 	_check_namespace($namespace);
-	
+
 	# List stores in this namespace
 	my @pages =
 		grep { m/^:/ and s/^\Q$namespace\E:*([^:]+:*)$/$1:/ } keys %$self;
@@ -498,20 +546,20 @@ sub _clone { # Copy and move are almost the same
 	my ($method, $self, $source, $target, $update) = @_;
 	_check_page($source);
 	_check_page($target);
-	
+
 	$source = $self->get_page($source)
 		|| die "Could not open page '$source'\n"
 		unless ref $source;
 	$target = $self->get_page($target)
 		|| die "Could not create page '$target'\n"
 	       	unless ref $target;
-	
+
 	die "BUG: You tried to move a page marked as read-only\n"
 		if $method eq 'move_page' and $source->{properties}{read_only};
 	die "Page '$target' exists\n"
 		if $target->exists and ! $target->equals($source);
 		# if pages are equal the case can still differ
-	
+
 	if ($source->{store} eq $target->{store}
 		and $target->{store} ne $self
 	) {
@@ -604,7 +652,7 @@ sub interwiki_lookup {
 	if (exists $_urls{$key}) { $url = $_urls{$key} }
 	else { # file lookup
 		# TODO repository specific urls here
-		
+
 		if ($class->get_notebook($key)) {
 			# Named zim notebook - put key in url, not actual dir !
 			$url = "zim://$key?{NAME}";
@@ -628,7 +676,7 @@ sub interwiki_lookup {
 				sprintf("%%%02X", ord($1))/gex;
 		$url =~ s/{URL}/$page/ or $url .= $page;
 	}
-	
+
 	return $url;
 }
 
@@ -761,10 +809,10 @@ sub get_notebook_cache {
 	}
 
 	$dir = dir($dir) if defined $dir;
-		# FIXME if dir is an object already it can have a property 
-		# "slow_fs" should we check notebook.zim for this property 
+		# FIXME if dir is an object already it can have a property
+		# "slow_fs" should we check notebook.zim for this property
 		# if we get a path ?
-	
+
 	if (!defined $dir or $$dir{slow_fs} or ! $dir->writable) {
 		# use cache dir instead of notebook dir
 		# logic similar to login in cache_file() in FS.pm
@@ -810,7 +858,7 @@ Save a list of array references containing name and path for known notebooks.
 
 sub get_notebook {
 	my ($class, $name) = @_;
-	
+
 	if ($name eq '_doc_') {
 		my $path = data_dirs(qw/zim doc/);
 		return dir( $path );
@@ -865,7 +913,7 @@ sub set_notebook_list {
 Checks if DIR is under one of the supported version control systems and
 returns an object for the root dir of the version control repository or undef.
 
-=cut 
+=cut
 
 sub check_version_control {
 	my (undef, $dir) = @_;
