@@ -20,7 +20,7 @@ my $has_mimeapplications = $@ ? 0 : 1;
 warn "WARNING: Could not use 'File::MimeInfo::Applications', disabling application bindings\n"
 	unless $has_mimeapplications;
 
-our $VERSION = '0.26';
+our $VERSION = '0.29';
 our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
@@ -30,13 +30,13 @@ Zim::GUI - The application object for zim
 =head1 SYNOPSIS
 
 	use Zim::GUI;
-	
+
 	my $zim = Zim::GUI->new(\%SETTINGS);
 	$zim->gui_init;
 	$zim->gui_show;
-	
+
 	Gtk2->main;
-	
+
 	exit;
 
 =head1 DESCRIPTION
@@ -45,7 +45,7 @@ This is developer documentation, for the user manual try
 executing C<zim --doc>. For commandline options see L<zim>(1).
 
 This module provides the application object for the Gtk2 application B<zim>.
-The application has been split into several components for which the 
+The application has been split into several components for which the
 modules can be found in the Zim::GUI:: namespace. This object brings
 together these components and manages the settings and data objects.
 
@@ -155,6 +155,7 @@ follow_new_link	0
 backsp_unindent	1
 plugins		Calendar,TODOList,PrintToBrowser
 use_camelcase	1
+use_ucfirst_title	1
 use_utf8_ent	1
 use_linkfiles	1
 use_autolink	0
@@ -163,7 +164,7 @@ textfont
 tearoff_menus	0
 use_autoselect	1
 follow_on_enter	1
-use_ctrl_space	1
+use_ctrl_space	0
 ro_cursor	0
 expand_tree	0
 save_interval	5000
@@ -190,6 +191,7 @@ ToolsMenu	.		_Tools
 GoMenu		.		_Go
 HelpMenu	.		_Help
 PathBarMenu	.		P_athbar type
+ToolBarMenu	.		Toolbar style
 } );
 
 my $ui_actions = __actions(
@@ -238,14 +240,14 @@ About		gtk-about	_About		.		About
 } );
 
 my $ui_toggle_actions = __actions(
-# name,		stock id,	label,		accelerator,	tooltip 
+# name,		stock id,	label,		accelerator,	tooltip
 q{
 TToolBar	.		_Toolbar	.		Show toolbar
 TStatusBar	.		_Statusbar	.		Show statusbar
 TPane		gtk-index	_Index		F9		Show index
 } );
 
-my $ui_radio_actions = __actions(
+my $ui_radio_PBactions = __actions(
 # name,		stock id,	label,		accelerator,	tooltip
 q{
 PBRecent	.		_Recent pages	.		.
@@ -253,6 +255,23 @@ PBHistory	.		_History	.		.
 PBNamespace	.		_Namespace	.		.
 PBHidden	.		H_idden		.		.
 } );
+my $ui_radio_TBaction_iconsize = __actions(
+# name,		stock id,	label,		accelerator,	tooltip
+q{
+TBmenu		.		Tiny		.		.
+TBsmall-toolbar	.		Small		.		.
+TBbutton	.		Medium		.		.
+TBlarge-toolbar	.		Large		.		.
+TBdnd		.		Big		.		.
+TBdialog	.		Fat		.		.
+} );
+
+my $ui_radio_TBaction_style = __actions(
+q{
+TBtext		.		_Text	.		.
+TBicons		.		_Icons 	.		.
+TBboth		.		_Both	.		.
+} );
 
 my $ui_layout = q{<ui>
 	<menubar name='MenuBar'>
@@ -292,6 +311,18 @@ my $ui_layout = q{<ui>
 				<menuitem action='PBNamespace'/>
 				<menuitem action='PBHidden'/>
 			</menu>
+			<menu action='ToolBarMenu'>
+				<menuitem action='TBmenu'/>
+				<menuitem action='TBsmall-toolbar'/>
+				<menuitem action='TBbutton'/>
+				<menuitem action='TBlarge-toolbar'/>
+				<menuitem action='TBdnd'/>
+				<menuitem action='TBdialog'/>
+				<separator/>
+				<menuitem action='TBtext'/>
+				<menuitem action='TBicons'/>
+				<menuitem action='TBboth'/>
+			</menu>
 			<separator/>
 			<placeholder name='PluginItems'/>
 			<separator/>
@@ -369,6 +400,18 @@ my $ui_layout = q{<ui>
 		<menuitem action='popup_RenamePage'/>
 		<menuitem action='popup_DeletePage'/>
 	</popup>
+	<popup name='ToolBarPopup'>
+		<menuitem action='TBmenu'/>
+		<menuitem action='TBsmall-toolbar'/>
+		<menuitem action='TBbutton'/>
+		<menuitem action='TBlarge-toolbar'/>
+		<menuitem action='TBdnd'/>
+		<menuitem action='TBdialog'/>
+		<separator/>
+		<menuitem action='TBtext'/>
+		<menuitem action='TBicons'/>
+		<menuitem action='TBboth'/>
+	</popup>
 	<accelerator action='GoChild'/>
 </ui>};
 
@@ -399,12 +442,12 @@ sub init {
 	$self->{app} = $self; # fool base class
 	$self->{_message_timeout} = -1;
 	$self->{_save_timeout}    = -1;
-	
+
 	# check notebook
 	my $notebook = $self->{notebook} or die "BUG: no notebook defined";
 	$self->{history} = $notebook->init_history;
 	$self->{profile} ||= $$notebook{config}{profile} || 'default';
-	
+
 	# load state parameters
 	my %state;
 	for (split /\n/, $STATE) { # defaults
@@ -468,11 +511,11 @@ sub _load_settings {
 sub _init_properties {
 	my $self = pop; # pop because we are called from signal
 	my $nb = $$self{notebook};
-	
+
 	# name
 	$self->call_daemon('register', $$nb{name});
 	warn "# Notebook: $$nb{name}\n";
-	
+
 	# icon
 	if (my $icon = $$nb{config}{icon}) {
 		my $file = Zim::FS->abs_path($icon, $$nb{dir});
@@ -544,12 +587,12 @@ sub gui_init {
 	else {
 		$window->set_icon_from_file($Zim::ICON);
 	}
-	$window->set_title('Zim');
+	$window->set_title($$self{notebook}{name}.' - Zim');
 	$self->{window} = $window;
 
 	$SIG{USR1} = sub { $window->present };
 		# put window to foreground on `kill -USR1`
-	
+
 	#$window->signal_connect(hide => sub { # FIXME does not work - patched in TrayIcon
 	#		@{$self->{state}}{'x', 'y'} = $window->get_position;
 	#		warn "hiding window: @{$self->{state}}{'x', 'y'}\n";
@@ -559,7 +602,7 @@ sub gui_init {
 			#warn "showing window: $x, $y\n";
 			$window->move($x,$y) if defined($x) and defined ($y);
 		} );
-			
+
 
 	my $vbox = Gtk2::VBox->new(0, 0);
 	$window->add($vbox);
@@ -570,12 +613,14 @@ sub gui_init {
 	$window->add_accel_group($ui->get_accel_group);
 	$ui->set_add_tearoffs($self->{settings}{tearoff_menus});
 	$self->{ui} = $ui;
-	
+
 	$self->add_actions($ui_menus, 'MENU');
 	$self->add_actions($ui_actions);
 	$self->add_actions($ui_toggle_actions, 'TOGGLE');
-	$self->add_actions($ui_radio_actions, 'RADIO', 'TPathBar');
-	
+	$self->add_actions($ui_radio_PBactions, 'RADIO', 'TPathBar');
+	$self->add_actions($ui_radio_TBaction_iconsize, 'RADIO', 'TBar_iconsize');
+	$self->add_actions($ui_radio_TBaction_style, 'RADIO', 'TBar_style');
+
 	$self->actions_set_sensitive(
 		Save      => $$self{read_only} ? 0 : 1,
 		NewPage   => $$self{read_only} ? 0 : 1,
@@ -585,17 +630,24 @@ sub gui_init {
 		OpenRootFolder  => $$self{notebook}{document_root} ? 1 : 0,
 		Versions        => $$self{notebook}{vcs} ? 1 : 0,
 	);
-	
+
 	$self->add_ui($ui_layout);
 	$self->add_ui($ui_layout_rw) unless $self->{read_only};
 		# we do not load menu items for edit whith global read_only
-	
+
 	$self->{menubar} = $ui->get_widget("/MenuBar");
 	$vbox->pack_start($self->{menubar}, 0,1,0);
 	$self->{toolbar} = $ui->get_widget("/ToolBar");
 	$vbox->pack_start($self->{toolbar}, 0,1,0);
 	$self->{toolbar}->hide;
 	$self->{toolbar}->set_no_show_all(1);
+	$self->{toolbar}->signal_connect('popup_context_menu' => sub {
+		my $self = shift; # Gtk2::Toolbar
+		my ($x, $y, $b, $pop) = @_;
+		$pop->popup(undef, undef, undef, undef, 0, 0);
+	    },
+	    $ui->get_widget("/ToolBarPopup"),
+	);
 
 	## General window layout
 	my $hpaned = Gtk2::HPaned->new();
@@ -616,7 +668,7 @@ sub gui_init {
 	$shbox->set_no_show_all(1);
 	$vbox->pack_start($shbox, 0,1,0);
 	$self->{statusbar} = $shbox;
-	
+
 	## Status bar
 	# Page name part
 	my $s1 = Gtk2::Statusbar->new;
@@ -652,7 +704,7 @@ sub gui_init {
 	$s2->set_size_request(80,10);
 	$shbox->pack_end($s2, 0,1,0);
 	$self->{status2} = $s2;
-	
+
 	$ebox->signal_connect_swapped(button_press_event => \&on_click_backlinks, $self);
 
 	## Build content of the main area
@@ -666,7 +718,7 @@ sub gui_init {
 
 	$vbox->set_focus_chain($l_vbox, $page_view->widget);
 		# get pathbar and toolbar out of the loop
-	
+
 	my $hist = $self->{history};
 	$hist->set_GUI($page_view) if $hist;
 
@@ -675,7 +727,7 @@ sub gui_init {
 	# Ctrl-Space / Alt-Space
 	my @combo = ([ord(' '), ['mod1-mask']]);
 	push @combo, [ord(' '), ['control-mask']] if $self->{settings}{use_ctrl_space};
-	$accels->connect( 
+	$accels->connect(
 		@$_, ['visible'],
 		sub {
 			if ($self->{state}{pane_vis}) {
@@ -760,14 +812,14 @@ sub gui_init {
 
 =item C<gui_show()>
 
-This method actually shows the main window. This is separated from 
+This method actually shows the main window. This is separated from
 C<gui_init()> so we can first load a page before showing the GUI.
 
 =cut
 
 sub gui_show {
 	my ($self, %opt) = @_;
-	
+
 	## Show all widgets .. well most of them
 	$self->{ui}->ensure_update; # make sure the menu is complete
 	$self->{vbox}->show_all;
@@ -775,18 +827,22 @@ sub gui_show {
 	$self->{l_vbox}->set_no_show_all(0);
 	$self->{toolbar}->set_no_show_all(0);
 	$self->ShowWindow(%opt); # run before "load_page" to prevent lag
-	
+
 	## Find a page to load
 	my $hist = $self->{history};
 	unless ($self->{page}) {
-		my $page = $hist ? $hist->get_current : undef;
-		$page ||= $self->{home};
-		$page = ref($page)
-			? $page
-			: $self->{notebook}->resolve_page($page);
+		my $page;
+		$page = $$self{history}->get_current if $$self{history} ;
+		$page ||= $$self{notebook}->resolve_page($$self{home})
+			if $$self{home};
+		unless ($page) {
+			# last ditch effort
+			($page) = $$self{notebook}->list_pages(':');
+			$page = $$self{notebook}->resolve_name($page);
+		}
 		$self->load_page($page);
 	}
-	
+
 	## Toggle some widgets
 	$self->{message_lock} = 1;
 	$self->TReadOnly($$self{page}{properties}{read_only}||0, 'FORCE');
@@ -804,13 +860,17 @@ sub gui_show {
 	$self->TPathBar($pbtype);
 	$self->{message_lock} = 0;
 
+	## set toolbar styles
+	$self->TBar_style($$set{toolbar_style} || $self->{toolbar}->get_style);
+	$self->TBar_iconsize($$set{toolbar_iconsize} || $self->{toolbar}->get_icon_size);
+
 	## set autosave interval - default is every 5 seconds
 	my $t = $$set{save_interval} || 5000;
-	$self->{_save_timeout} = 
+	$self->{_save_timeout} =
 		Glib::Timeout->add($t, sub {$self->SaveIfModified('SOFT'); 1})
 		unless $self->{read_only};
 		# global read-only - so we never need to save
-	
+
 	$self->signal_emit('gui_show');
 	$self->PageView->grab_focus;
 }
@@ -885,11 +945,11 @@ sub AUTOLOAD {
 	my $self = shift;
 	my $class = ref $self;
 	$AUTOLOAD =~ s/^.*:://;
-	
+
 	return if $AUTOLOAD eq 'DESTROY';
 	croak "No such method: $class::$AUTOLOAD" unless ref $self;
 	#warn join ' ', "Zim::AUTOLOAD called for $AUTOLOAD by: ", caller, "\n";
-	
+
 	if (exists $self->{objects}{$AUTOLOAD}) {
 		return $self->{objects}{$AUTOLOAD};
 	}
@@ -899,7 +959,7 @@ sub AUTOLOAD {
 		goto &{"Zim::GUI::Component::$AUTOLOAD"}; # call parent
 	}
 	elsif ($AUTOLOAD =~ /^[A-Z]/) {
-		my $class = $$self{autoload}{$AUTOLOAD}; 
+		my $class = $$self{autoload}{$AUTOLOAD};
 		$class ||= "Zim::GUI::$AUTOLOAD";
 		warn "## AUTOLOAD $class\n";
 		eval "require $class";
@@ -908,7 +968,7 @@ sub AUTOLOAD {
 		return $self->{objects}{$AUTOLOAD};
 	}
 
-	
+
 	# Call method on default widget
 	croak "No such method: $class::$AUTOLOAD"
 		unless $$self{window} and $$self{window}->can($AUTOLOAD);
@@ -939,7 +999,7 @@ sub plug { # TODO add plugin to config
 	return $self->error_dialog(
 		__("Plugin already loaded: {name}", name => $name) )
 		if $self->{plugins}{$name};
-		
+
 	my ($script) = data_files('zim', 'plugins', $name.'.pl');
 	unless (length $script) {
 		$self->unplug($name);
@@ -972,17 +1032,17 @@ sub unplug {
 sub on_click_backlinks {
 	my ($self, $event) = @_;
 	return if $event->type ne 'button-press';
-	
+
 	if ($event->button == 1) {
 		$self->SearchDialog->{dialog}
 			? $self->SearchDialog->hide
 			: $self->SearchBL  ;
 	}
 	return unless $event->button == 3;
-	
+
 	my @blinks = $self->{page}->list_backlinks;
 	return unless @blinks;
-	
+
 	my $menu = Gtk2::Menu->new();
 	for my $l (@blinks) {
 		my $item = Gtk2::ImageMenuItem->new_with_label($l);
@@ -992,7 +1052,7 @@ sub on_click_backlinks {
 	}
 
 	$menu->show_all;
-	
+
 	my ($button, $time) = $event
 		? ($event->button, $event->time)
 		: (0, 0) ;
@@ -1026,6 +1086,7 @@ sub SaveSettings {
 	my $file = config_home('zim', $$self{profile}.'.conf');
 	warn "# Writing config to: $file\n";
 	Zim::FS::File::Config->new($file)->write(\%conf, 'Config');
+	$self->signal_emit('settings-changed');
 	$self->call_daemon('broadcast', 'LoadSettings') if $notify;
 }
 
@@ -1093,7 +1154,7 @@ sub link_clicked {
 	warn "## Link clicked: $link ($type: $l)\n";
 	return $self->error_dialog("Link undefined: $link")
 	       unless defined $type;
-	
+
 	if    ($type eq 'page') { $self->load_page($l) }
 	elsif ($type eq 'file') { $self->open_file($l) }
 	elsif ($type eq 'zim') {
@@ -1117,7 +1178,7 @@ sub open_file {
 	my ($self, $file) = @_;
 	return $self->open_directory($file) if $file =~ /\/$/ or -d $file;
 		# Just to make sure we are dealing with files here
-	
+
 	my $app;
 	if ($has_mimeapplications) {
 		my $mt = mimetype("$file");
@@ -1154,10 +1215,10 @@ sub open_directory {
 	my ($self, $dir, $open_file) = @_;
 		# open_file is a private arg used by open_file() to
 		# flag that we try to open a file instead of a dir
-	
+
 	my $browser = $self->_ask_app('file_browser', __('File browser')) #. application type
 		or return 0;
-	
+
 	$dir = Zim::FS->localize($dir);
 	my $file = $dir;
 	if ($open_file or -f $dir) {
@@ -1165,7 +1226,7 @@ sub open_directory {
 		my ($vol, $dirs, undef) = File::Spec->splitpath($dir);
 		$dir = File::Spec->catpath($vol, $dirs);
 	}
-	
+
 	unless (-d $dir) {
 		# Check existense of the directory part
 		my $answer = $self->prompt_question( 'question',
@@ -1188,7 +1249,7 @@ sub open_directory {
 		$browser =~ s/\%([fds])/$dir/eg
 			or $browser .= " \"$dir\"";
 	}
-	
+
 	Zim::Utils->run($browser);
 	return 1;
 }
@@ -1223,7 +1284,7 @@ Opens URL in the web browser.
 sub open_url {
 	my ($self, $url, $type) = @_;
 	# type is a private argument used for error handling for interwiki
-	
+
 	$url =~ /^(\w[\w\+\-\.]+):/
 		or return $type
 			? $self->error_dialog(
@@ -1231,7 +1292,7 @@ sub open_url {
 			: $self->error_dialog(
 				__("Not an url: {url}", url => $url)) ;
 	my $proto = $1;
-	
+
 	my ($app, $string) = ($proto eq 'mailto')
 		? ('email_client', __('Email client'))   #. application type
 		: ('browser',      __('Web browser' )) ; #. application type
@@ -1262,20 +1323,20 @@ sub load_page {
 sub _load_page { # load _without_ saving first
 	my ($self, $page) = @_;
 	my $prevpage = $self->{page};
-	
+
 	# See if we got a name, a page or a history record
 	my ($rec, $name);
-	($name, $page, $rec) = 
+	($name, $page, $rec) =
 		(ref($page) eq 'HASH') ? ($page->{name}, undef, $page) :
 		 ref($page)            ? ($page->name,   $page, undef) :
 		                         ($page,         undef, undef) ;
 	warn "## GUI load_page: $name (obj: $page rec: $rec)\n";
-	
+
 	# Get page if we didn't get it as argument
 	unless ($page) {
 		return warn "WARNING: You tried to load an empty name.\n"
 			unless length $name;
-		
+
 		eval { $page = $self->{notebook}->get_page($name) };
 		return $self->error_dialog(
 			__("Could not load page: {name}", name => $name)."\n\n$@", $@) if $@;
@@ -1292,7 +1353,7 @@ sub _load_page { # load _without_ saving first
 		$page->{properties}{read_only} = 1;
 		$page->{properties}{is_error} = 404;
 	}
-	
+
 	# Update history if we didn't get a record as argument
 	# if we did get a record it is from GoBack() or GoForw()
 	# and the history is updated already
@@ -1308,7 +1369,7 @@ sub _load_page { # load _without_ saving first
 		$self->exit_error(__("Could not load page: {name}", name => $name)."\n\n$@", $@);
 		# TODO handle more gratiously .. use read_only ?
 	}
-	
+
 	# Update various objects
 	$self->{objects}{PageView}->set_state($rec->{state})
 		if $rec and $rec->{state};
@@ -1317,8 +1378,7 @@ sub _load_page { # load _without_ saving first
 		and (defined $prevpage and ! $prevpage->exists);
 	$self->TReadOnly($$page{properties}{read_only}||0);
 	$self->signal_emit('page_loaded', $name);
-	
-	$self->{window}->set_title("$name - Zim");
+
 	$self->update_status();
 	my $links = scalar $page->list_backlinks;
 	$self->{statusl}->set_text_with_mnemonic(
@@ -1348,7 +1408,7 @@ sub TReadOnly {
 	);
 	#warn "Emit t_read_only => $read_only\n";
 	$self->signal_emit(t_read_only => $read_only);
-	$self->update_status; 
+	$self->update_status;
 		# We want to show "[read-only]" in the statusbar
 }
 
@@ -1371,8 +1431,8 @@ PAGE is used to fill in the namespace in the dialog.
 sub NewPage {
 	my ($self, $ns) = @_;
 
-	if (defined $ns) { $ns =~ s/[^:]+$// }
-	else { $ns = $self->{page}->namespace }
+	$ns ||= $self->{page};
+	$ns =~ s/:?$/:/;
 	$ns = '' if $ns eq ':';
 
 	my $values = $self->run_prompt(
@@ -1390,7 +1450,7 @@ sub NewPage {
 
 	$self->load_page(
 		$self->{notebook}->resolve_name($page, $self->{page}) );
-	
+
 	$self->Save unless $$self{page}->exists; # touch new page
 }
 
@@ -1409,7 +1469,7 @@ sub OpenNotebook {
 
 	# first try the daemon
 	$self->call_daemon('open', $notebook, $page) and return;
-	
+
 	# We are not using daemon or daemon failed
 	return $self->NotebookDialog->show() if $notebook eq '_new_';
 		# Don't wait for return - NotebookDialog is not modal
@@ -1448,9 +1508,9 @@ sub SaveIfModified {
 	return 1 if $self->{read_only};
 		# even if modified due to bug no save for read_only
 	return 0 if $self->{save_lock} and $soft;
-	
+
 	my $modified = $self->{objects}{PageView}->modified;
-	
+
 	warn "## GUI SaveIfModified\n" if $modified;
 	return $self->_save_page($modified, !$soft);
 }
@@ -1460,7 +1520,7 @@ sub SaveIfModified {
 sub _save_page {
 	my ($self, $save, $commit) = @_;
 	$self->{save_lock} = 1; # Used to block autosave while "could not save" dialog
-	
+
 	my $page = $self->{page};
 	eval {
 		$self->PageView->save_page($page) if $save;
@@ -1471,7 +1531,7 @@ sub _save_page {
 		warn 'ERROR: '.$error;
 		my $answer = $self->prompt_question( 'error',
 			'<b>'.__("Could not save page")."</b>\n\n$error", # dialog message
-			['cancel', 'gtk-cancel', undef ], 
+			['cancel', 'gtk-cancel', undef ],
 			['discard', 'gtk-delete', __('_Discard changes')], #. dialog button
 			['copy', 'gtk-save-as', __('_Save a copy...')], #. dialog button
 			3 );
@@ -1510,7 +1570,7 @@ Prompt user to initialize version control, called by C<SaveVersion()>.
 sub SaveVersion {
 	my ($self, $comment) = @_;
 	$self->SaveIfModified or return;
-	
+
 	return $self->init_vcs_dialog unless $$self{notebook}{vcs};
 
 	# saved log
@@ -1522,6 +1582,7 @@ sub SaveVersion {
 		$comment =~ s/\n?$/\n\n/ if $comment =~ /\S/;
 		$comment .= $log->read;
 	}
+	else { $comment ||= "Saved version from zim" }
 
 	# prompt for comment
 	my $dialog = Gtk2::Dialog->new(
@@ -1533,7 +1594,7 @@ sub SaveVersion {
 	);
 	#$dialog->vbox->set_spacing(5);
 	$dialog->set_default_size(300, 150);
-	
+
 	my $vpane = Gtk2::VPaned->new;
 	$dialog->vbox->add($vpane);
 	my $vbox1 = Gtk2::VBox->new;
@@ -1555,7 +1616,7 @@ sub SaveVersion {
 	$label->set_use_markup(1);
 	$label->set_alignment(0,0.5);
 	$vbox2->pack_start($label, 0,1,0);
-	
+
 	my ($stscroll, $stview) = $self->new_textview(
 		$$self{notebook}{vcs}->status );
 	$vbox2->add($stscroll);
@@ -1597,25 +1658,52 @@ sub Versions { pop->VersionsDialog->show() }
 
 sub init_vcs_dialog {
 	my $self = shift;
-	
+
 	my $text = __("<b>Enable Version Control</b>\n\nVersion control is currently not enabled for this notebook.\nDo you want to enable it ?") #. question dialog, options are 'help', 'cancel' and 'ok'
 	         . "\n\n"
-		 . __("Enabling version control will initialize the <b>Bazaar</b> Version Control System.\nPlease click 'help' to read about the system requirements and alternatives.") ; #. detailed notice in prompt to enable version control
+		 . __("You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.\nPlease click 'help' to read about the system requirements.") ; #. detailed notice in prompt to enable version control
 	my $answer = $self->prompt_question(
 		'question', $text,
 		[help   => 'gtk-help'],
 		[cancel => 'gtk-cancel'],
-		[ok     => 'gtk-ok'] );
-	if ($answer eq 'ok') {
-		eval { $$self{notebook}->init_vcs('Bazaar') };
+		[svn    => undef, 'Subversion' ],
+		[bzr    => undef, 'Bazaar'],
+	);
+
+	my $vcs = undef;
+	my $args = {};
+	if ($answer eq 'bzr') { $vcs = 'Bazaar' }
+	elsif ($answer eq 'svn') {
+		my $val = $self->run_prompt(
+			'Enter SVN repository',
+			['url','username','password'],
+			{
+				url => ['SVN repository URL', 'string', 'http://'],
+				username => ['Username', 'string', ''],
+				password => ['Password', 'password', ''],
+			}
+		);
+		return unless $val;
+		$args = {
+			'url' => $$val[0],
+			'username' => $$val[1],
+			'password' => $$val[2],
+		};
+		$vcs = 'Subversion';
+	}
+	elsif ($answer eq 'help') {
+		$self->ShowHelp(':Usage:VersionControl');
+		return;
+	}
+	else { return }
+
+	if (defined $vcs) {
+		eval { $$self{notebook}->init_vcs($vcs, $args) };
 		return $self->error_dialog( __('Could not initialize version control')."\n\n$@" ) if $@ or ! $$self{notebook}{vcs}; #. error dialog
 		$self->Reload; # purge page object
 		$self->actions_set_sensitive(Versions => 1);
 		$self->SaveVersion( __("Initial version") ) # indirect recurs #. default comment for first version after initializing version control
 	}
-	elsif ($answer eq 'help') {
-		$self->ShowHelp(':Usage:VersionControl');
-	}
 }
 
 =item C<Export()>
@@ -1637,6 +1725,7 @@ sub EmailPage {
 	$self->SaveIfModified or return;
 	my $subject = $self->{page}->name;
 	my $src = $self->{page}->get_text;
+	$src =~ s/^Content-Type:.*?\n\n//s; # get rid of headers
 	$src =~ s/(\W)/sprintf '%%%02x', ord $1/eg; # url encoding
 	$self->open_url("mailto:?subject=$subject&body=".$src);
 }
@@ -1650,7 +1739,7 @@ Prompt the user to save a copy of the current page.
 sub CopyPage {
 	my ($self, $page) = @_;
 	$page ||= $$self{page};
-	
+
 	my $copy_current = $$self{page}->equals($page);
 	my $save = $self->SaveIfModified(!$copy_current);
 	return 0 if $copy_current and !$save;
@@ -1671,7 +1760,7 @@ sub CopyPage {
 	return $self->error_dialog(
 		__("Can not save to page: {name}", name => $l) )
 		unless $new;
-	
+
 	# check if page exists
 	if ($new->exists()) {
 		my $answer = $self->prompt_question( 'warning',
@@ -1680,11 +1769,11 @@ sub CopyPage {
 			['overwrite', undef, __('_Overwrite')] ); #. save button
 		return unless $answer eq 'overwrite';
 	}
-	
+
 	# finally copy page
 	$$self{notebook}->copy_page($page => $new);
 	$self->signal_emit(page_created => $new);
-	
+
 	return 1;
 }
 
@@ -1708,11 +1797,11 @@ sub RenamePage {
 	my ($self, $from, $to, @update) = @_;
 
 	$from = $self->{page}->name unless defined $from;
-	
+
 	my $move_current = $self->{page}->equals($from);
 	my $save = $self->SaveIfModified(!$move_current);
 	return 0 if $move_current and !$save;
-	
+
 	unless (defined $to) {
 		($to, @update) = $self->prompt_rename_page_dialog($from);
 		$self->check_page_input($to);
@@ -1729,7 +1818,7 @@ sub RenamePage {
 	# Get backlinks
 	my $rfrom = $move_current ? $self->{page} : $self->{notebook}->get_page($from); # FIXME ugly lookup
 	my @backlinks = $rfrom->list_backlinks();
-	
+
 	# Move page
 	#warn "Move '$from' to '$to'\n";
 	eval { $self->{notebook}->move_page($from, $to) };
@@ -1769,12 +1858,12 @@ sub RenamePage {
 		$self->error_dialog($@) if $@;
 		$dialog->destroy;
 	}
-	
+
 	warn "# moved $from => $to\n";
 	$self->{history}->delete_recent("$from") if $self->{history};
 	$self->signal_emit('page_renamed', $from => $to);
 	$self->load_page($to) if $move_current;
-	
+
 	$self->update_status;
 	return 1;
 }
@@ -1792,15 +1881,15 @@ TODO: make recusive delete work
 
 sub DeletePage {
 	# FIXME option to delete a complete sub-tree
-	# FIXME integrate with the save_page() logic, now we have 
+	# FIXME integrate with the save_page() logic, now we have
 	# redundant code here
 	my ($self, $page, undef, $noconf) = @_;
 	$page = $self->{page}->name unless defined $page;
-	
+
 	my $name = ref($page) ? $page->name : $page;
 	my $delete_current = ($name eq $self->{page}->name);
 	$self->SaveIfModified(!$delete_current);
-	
+
 	unless ($noconf) {
 		my $r = $self->prompt_question( 'warning',
 		__("<b>Delete page</b>\n\nAre you sure you want to delete\npage '{name}' ?", name => $name), #. warning dialog, answers are 'cancel' or 'delete'
@@ -1808,7 +1897,7 @@ sub DeletePage {
 			['yes', 'gtk-delete', undef]  );
 		return unless $r eq 'yes';
 	}
-	
+
 	$page = $self->{page} if $delete_current; # make sure we have the right object
 	eval { $self->{notebook}->delete_page($page) };
 	return $self->error_dialog(
@@ -1864,7 +1953,7 @@ sub on_delete_event {
 		@{$state}{'x', 'y'} = $window->get_position if $window->visible;
 			# position is 0,0 when window is hidden
 	};
-	
+
 	# save state etc. no matter if we really destruct or not
 	$self->SaveIfModified() || return 1;
 	$self->SaveState;
@@ -1873,7 +1962,7 @@ sub on_delete_event {
 	# Hide window already to make it look snappy
 	$$self{window}->hide;
 	while (Gtk2->events_pending) { Gtk2->main_iteration_do(0) }
-	
+
 	# clean up tmp files - match name Zim::FS->tmp_file
 	my $dir = dir( Zim::FS->tmpdir );
 	my @files = grep /^zim-$ENV{USER}-$$-/, $dir->list;
@@ -1881,15 +1970,22 @@ sub on_delete_event {
 		eval { $dir->file($_)->remove };
 		warn $@ if $@;
 	}
-	
+
 	# check if we really destruct or not
 	return 1 if $$self{hide_on_delete} and !$force;
 
 	# autosave version
-	eval { $$self{notebook}{vcs}->commit("autosave from zim") }
+	eval { $$self{notebook}{vcs}->commit("Autosave version from zim") }
 		if  $$self{notebook}{vcs}
 		and $$self{notebook}{config}{autosave_version} ;
 
+	# check umounting
+	my $mount = $$self{notebook}{automount};
+	eval {
+		my $path = $$self{notebook}{file} || $$self{notebook}{dir} ;
+		Zim::GUI::Automount->umount($path, $mount);
+	} if $mount ;
+
 	return 0 
 }
 
@@ -2042,7 +2138,7 @@ sub on_TPathBar {
 sub TPathBar {
 	my ($self, $type) = @_;
 	return warn "BUG: No pathbar type given" unless defined $type;
-	
+
 	my $path_bar = $self->{objects}{PathBar};
 	if (grep {$type eq $_} qw/recent history namespace/) {
 		$path_bar->widget->show_all;
@@ -2061,6 +2157,60 @@ sub TPathBar {
 	}
 }
 
+=item C<TBar_iconsize(SIZE)>
+
+Set the toolbar type to Gtk2::IconSize SIZE.
+
+=cut
+
+sub on_TBar_iconsize { # Gtk2::RadioAction, Gtk2::RadioAction, ZIM::GUI
+	my $self = pop;
+	return if $self->{_block_actions};
+	my $action = pop;
+	$action = lc substr($action->get_name, 2);
+	$self->TBar_iconsize($action);
+}
+
+sub TBar_iconsize {
+	my ($self, $type) = @_;
+	return warn "BUG: No toolbar type given" unless defined $type;
+	my $tool_bar = $self->{toolbar};
+	$tool_bar->set_icon_size($type);
+
+	$self->actions_show_active("TB$type" => 1);
+	unless ($$self{settings}{toolbar_iconsize} eq $type) {
+		$$self{settings}{toolbar_iconsize} = $type;
+		$self->SaveSettings; # not important enough for NOTIFY
+	}
+}
+
+=item C<TBar_style(VAL)>
+
+Set the toolbar type to Gtk2::ToolbarStyle
+
+=cut
+
+sub on_TBar_style { # Gtk2::RadioAction, Gtk2::RadioAction, ZIM::GUI
+	my $self = pop;
+	return if $self->{_block_actions};
+	my $action = pop;
+	$action = lc substr($action->get_name, 2);
+	$self->TBar_style($action);
+}
+
+sub TBar_style {
+	my ($self, $type) = @_;
+	return warn "BUG: No toolbar type given" unless defined $type;
+	my $tool_bar = $self->{toolbar};
+	$tool_bar->set_style($type);
+
+	$self->actions_show_active("TB$type" => 1);
+	unless ($$self{settings}{toolbar_style} eq $type) {
+		$$self{settings}{toolbar_style} = $type;
+		$self->SaveSettings; # not important enough for NOTIFY
+	}
+}
+
 =item C<Reload()>
 
 Save and reload the current page.
@@ -2106,7 +2256,7 @@ sub OpenFolder {
 	return $self->error_dialog(
 		__("This page does not have a document folder") ) #. error
 		unless $dir;
-	
+
 	# open_directory asks to create directory if it doesn't exist
 	my $ok = $self->open_directory($dir);
 	if (! $ok) {
@@ -2128,36 +2278,40 @@ sub OpenRootFolder {
 	$self->open_directory($dir);
 }
 
-=item C<EditSource()>
+=item C<EditSource(PAGE)>
 
-Open the current page in an external editor.
+Open PAGE or the current page in an external editor.
 
 =cut
 
 sub EditSource {
-	my $self = shift;
-	$self->SaveIfModified;
-	my $page = $self->{page};
+	my ($self, $page, $file) = @_; # file is a private argument
+	# If file is given it could be e.g. a config file, in this 
+	# case we do not do anything with pages.
+	unless ($file) {
+		$self->SaveIfModified;
+		$page ||= $self->{page};
+
+		# Write source to tmp file
+		return $self->error_dialog(__("This page does not have a source"))
+			unless $page->has_source;
+		my $fh = $page->open_source('r');
+		$file = Zim::FS->tmp_file('EditSource.txt');
+		$file->write(<$fh>);
+		$fh->close;
+	}
 
-	# Write source to tmp file
-	return $self->error_dialog(__("This page does not have a source"))
-		unless $page->has_source;
-	my $fh = $page->open_source('r');
-	my $file = Zim::FS->tmp_file('EditSource.txt');
-	$file->write(<$fh>);
-	$fh->close;
-	
 	# Find editor
 	my $editor = $self->_ask_app('text_editor', __('Text Editor')) #. application type
 		or return;
 	$editor =~ s/\%[sf]/$file/ or $editor .= " \"$file\"";
-	
+
 	# Execute - GUI will hang while waiting for system to return,
 	#           so we can be sure buffer is not modified in between.
 	warn "# Executing: $editor\n";
-	if (system($editor) == 0) {
+	if (system($editor) == 0 and defined $page) {
 		# Save source
-		$fh = $page->open_source('w');
+		my $fh = $page->open_source('w');
 		print $fh $file->read;
 		$fh->close;
 		$self->Reload;
@@ -2358,7 +2512,7 @@ sub About {
 		website => $Zim::WEBSITE,
 	);
 	$info{translator_credits} =~ s/^\n+//;
-	
+
 	if (Gtk2->CHECK_VERSION(2, 6, 0)) {
 		my $hook = sub {$self->link_clicked($_[1])};
 		Gtk2::AboutDialog->set_url_hook($hook);
@@ -2377,7 +2531,7 @@ sub About {
 		my $button = $self->new_button('gtk-help', '_More');
 		$dialog->add_action_widget($button, 'help');
 		$dialog->set_default_response('close');
-	
+
 		$dialog->vbox->add(
 			Gtk2::Image->new_from_file($Zim::ICON) );
 		my $text = $Zim::LONG_VERSION;
@@ -2386,7 +2540,7 @@ sub About {
 		$label->set_markup($text);
 		$label->set_justify('center');
 		$dialog->vbox->add($label);
-	
+
 		$dialog->show_all;
 		my $response = $dialog->run;
 		$dialog->destroy;
@@ -2458,14 +2612,14 @@ Returns new page name and update boolean.
 
 sub prompt_rename_page_dialog {
 	my ($self, $page) = @_;
-	
+
 	my ($dialog, $entries) = $self->new_prompt(
 		__('Rename page'), #. dialog title
 		['page'], {page =>
 			[__('Rename to'), 'page', $page] #. dialog label
-		}, 
+		},
 		'gtk-save', __('_Rename')  ); #. save button
-	
+
 	my ($entry) = @$entries;
 	$entry->select_region(length($1), -1) if $page =~ /^(.+:)/;
 
@@ -2482,7 +2636,7 @@ sub prompt_rename_page_dialog {
 	$check2->show;
 	$dialog->vbox->add($check1);
 	$dialog->vbox->add($check2);
-	
+
 	if ($dialog->run eq 'ok') { $page = $entry->get_text }
 	else                      { $page = undef            }
 	my $up1 = $check1->get_active;
