@@ -7,7 +7,7 @@ use Zim::Utils;
 use Zim::GUI::Component;
 use Zim::GUI::PropertiesDialog;
 
-our $VERSION = '0.26';
+our $VERSION = '0.29';
 our @ISA = qw/Zim::GUI::Component/;
 
 use constant {
@@ -235,6 +235,7 @@ sub _init {
 	$self->_select_default;
 
 	$dialog->show_all;
+	$list->grab_focus;
 	$$self{dialog} = $dialog;
 }
 
@@ -262,10 +263,11 @@ sub _check_open {
 	return unless $$self{use_daemon};
 	my ($list, $notebooks) = @$self{'list', 'notebooks'};
 	my @dirs = map $$_[1], Zim::GUI::Daemon->list;
+	@dirs = map {s/\/*$//; $_} @dirs;
 	@{$$list{data}} = map {
 		my $name = $$_[COL_NAME];
 		my $dir = Zim::FS->abs_path($$notebooks{$name}, $ENV{HOME});
-		$dir =~ s/\/?$/\//; # logic same as in Daemon
+		$dir =~ s/\/*$//;
 		my $open = (grep {$_ eq $dir} @dirs) ? 1 : 0 ;
 		[$name => $open];
 	} @{$$list{data}};
@@ -335,12 +337,12 @@ sub on_response {
 
 		my $name = $$list{data}[$i][COL_NAME];
 		my $path = Zim::FS->abs_path($$notebooks{$name}, $ENV{HOME});
-		unless (-d $path) {
-			$self->error_dialog(
-			__("No such directory: {name}", name => $path) #. error
-			);
-			return undef;
-		}
+		#unless (-d $path) {
+		#	$self->error_dialog(
+		#	__("No such directory: {name}", name => $path) #. error
+		#	);
+		#	return undef;
+		#}
 
 		if ($dialog->get_modal) {
 			# probably called by run()
@@ -406,7 +408,7 @@ sub prompt_notebook {
 			$file->write($config, 'Notebook')
 				if defined $file;
 			
-			$dir =~ s/$ENV{HOME}\/*/~\//;
+			$dir =~ s/\Q$ENV{HOME}\E\/*/~\//;
 			unless ($name =~ /\S/) {
 				$name = $dir;
 				$name =~ s/.*[\/\\]//;
