@@ -4,8 +4,9 @@ use strict;
 use vars '$AUTOLOAD';
 use Gtk2;
 use Gtk2::Ex::PathBar; # custom widget
+use Zim::Utils;
 
-our $VERSION = '0.18';
+our $VERSION = '0.27';
 
 =head1 NAME
 
@@ -102,7 +103,9 @@ sub update {
 
 sub _load_namespace {
 	my $self = shift;
-	my $namespace = $self->{app}->History->get_namespace();
+	my $namespace = $self->{app}{history}
+		? $self->{app}{history}->get_namespace()
+		: $self->{app}{page}->namespace ;
 	$namespace =~ s/^:+|:+$//g;
 	my @namespace = split /:+/, $namespace;
 	my $current = $self->{app}->{page}->name;
@@ -119,20 +122,19 @@ sub _load_namespace {
 	$self->{path_bar}->set_path(@namespace);
 	$self->{path_bar}->select_item($#current);
 	
+	my $tooltips = Gtk2::Tooltips->new();
 	for ($self->{path_bar}->get_items()) {
 		my $name = ':'.join(':', @{$_->{path_data}}) ;
-		$_->signal_connect(enter => sub {
-			$self->{app}->push_status("Go to \"$name\"", 'link') } );
-		$_->signal_connect(leave => sub {
-			$self->{app}->pop_status('link') } );
+		$tooltips->set_tip($_, $name);
 	}
 
 }
 
 sub _load_history {
 	my $self = shift;
+	return unless $self->{app}{history};
 
-	my ($i, @hist) = $self->{app}->History->get_history;
+	my ($i, @hist) = $self->{app}{history}->get_history;
 	my (@path, @names);
 	for (@hist) {
 		my $basename = $_->{basename};
@@ -151,19 +153,18 @@ sub _load_history {
 	$self->{path_bar}->set_path(@path);
 	$self->{path_bar}->select_item($i);
 
+	my $tooltips = Gtk2::Tooltips->new();
 	for ($self->{path_bar}->get_items) {
 		my $name = shift @names;
-		$_->signal_connect(enter => sub {
-			$self->{app}->push_status("Go to \"$name\"", 'link') } );
-		$_->signal_connect(leave => sub {
-			$self->{app}->pop_status('link') } );
+		$tooltips->set_tip($_, $name);
 	}
 }
 
 sub _load_recent {
 	my $self = shift;
+	return unless $self->{app}{history};
 	
-	my ($i, @recent) = $self->{app}->History->get_recent;
+	my ($i, @recent) = $self->{app}{history}->get_recent;
 	
 	my $string = join '/', map $_->{name}, @recent;
 	if ($self->{path_loaded} eq $string) {
@@ -181,12 +182,10 @@ sub _load_recent {
 	$self->{path_bar}->set_path(@path);
 	$self->{path_bar}->select_item($i);
 
+	my $tooltips = Gtk2::Tooltips->new();
 	for ($self->{path_bar}->get_items) {
 		my (undef, $name) = @{shift @path};
-		$_->signal_connect(enter => sub {
-			$self->{app}->push_status("Go to \"$name\"", 'link') } );
-		$_->signal_connect(leave => sub {
-			$self->{app}->pop_status('link') } );
+		$tooltips->set_tip($_, $name);
 	}
 }
 
@@ -198,7 +197,7 @@ sub on_path_clicked {
 		$self->{app}->load_page($name);
 	}
 	elsif ($self->{type} eq 'history') {
-		my $back = $self->{app}->History->get_state->{back};
+		my $back = $self->{app}{history}->get_state->{back};
 		$idx -= $back;
 		if    ($idx < 0) { $self->{app}->GoBack(-$idx)   }
 		elsif ($idx > 0) { $self->{app}->GoForward($idx) }
@@ -206,7 +205,7 @@ sub on_path_clicked {
 	}
 	elsif ($self->{type} eq 'recent') {
 		my ($name) = @$path;
-		my $rec = $self->{app}->History->jump($name);
+		my $rec = $self->{app}{history}->jump($name);
 		$self->{app}->load_page($rec);
 	}
 	# else bug
