@@ -6,7 +6,7 @@ use Gtk2;
 use Gtk2::SimpleList;
 use Zim::Utils;
 
-our $VERSION = '0.26';
+our $VERSION = '0.29';
 
 =head1 NAME
 
@@ -91,6 +91,10 @@ my %Labels = ( # setting => [label, tooltip]
 		__('Auto-increment numbered lists'), #. pref. label
 		__('Automatically increment items in a numbered list'), #. pref. tooltip
 	],
+	use_recurscheck => [
+		__('Check checkbox lists recursive'), #. pref. label
+		__('Checking a checkbox list item will also check any sub-items'), #. pref. tooltip
+	],
 	backsp_unindent => [
 		__('Use "Backspace" to un-indent'), #. pref. label
 		__("Use the \"Backspace\" key to un-indent bullet lists (Same as \"Shift-Tab\")"), #. pref. tooltip
@@ -111,6 +115,10 @@ my %Labels = ( # setting => [label, tooltip]
 		__('Expand side pane'), #. pref. label
 		__("Start the side pane with the whole tree expanded."), #. pref. tooltip
 	],
+	use_ucfirst_title => [
+		__('Uppercase Title'), #. pref. label
+		__("Set first character to uppercase if title contains no uppercase character."), #. pref. tooltip
+	],
 );
 
 sub show {
@@ -245,6 +253,8 @@ sub show {
 		use_autoincr
 		use_autoselect
 		backsp_unindent
+		use_recurscheck
+		use_ucfirst_title
 	/;
 	$table = Gtk2::Table->new(scalar(@settings), 1);
 	$table->set_row_spacings(5);
