@@ -7,18 +7,19 @@
 # TRANSLATORS:
 # Frederik 'Freso' S. Olesen (da)
 # Jeppe Toustrup (da)
+# nanker (da)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-07 18:56+0000
-# Last-Translator: Jeppe Toustrup <launchpad@tenzer.dk>
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2009-11-18 01:32+0000
+# Last-Translator: nanker <Unknown>
 # Language-Team: Danish <da@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2010-01-10 10:44+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -64,12 +65,7 @@ eksisterer allerede.
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '<b>Genopret side til gemt version?</b>
-
-Ønsker du at genoprette siden: {page}
-til den gemte version: {version}?
-
-Alle ændringer lavet siden den version vil gå tabt!',
+All changes since the last saved version will be lost !' => '',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -106,15 +102,20 @@ opretter navnerum for hver måned.
   'Bold' => 'Fed',
   'Calen_dar|Show calendar' => '_Kalender|Vis kalender',
   'Calendar' => 'Kalender',
+  'Can not find application "bzr"' => 'Kan ikke finde applikation "bzr"',
+  'Can not find application "{name}"' => 'Kan ikke finde applikation "{name}"',
   'Can not save a version without comment' => 'Det er ikke muligt at gemme uden en kommentar',
-  'Can not save to page: {name}' => 'Siden "{name}" kan ikke gemmes til',
+  'Can not save to page: {name}' => 'Siden "{name}" kan ikke gemmes',
   'Can\'t find {url}' => 'Adressen "{url}" kunne ikke findes',
   'Cha_nge' => '_Redigér',
   'Chars' => 'Tegn',
   'Check _spelling|Spell check' => 'Kontrollér stavemåder|Start kontrol af stavemåder',
+  'Check checkbox lists recursive' => '',
+  'Checking a checkbox list item will also check any sub-items' => '',
   'Choose {app_type}' => 'Vælg {app_type}',
   'Co_mpare Page...' => 'S_ammeling side',
   'Command' => 'Kommando',
+  'Comment' => 'Kommentar',
   'Compare this version with' => 'Sammeling denne version med',
   'Copy Email Address' => 'Kopiér _post adresse',
   'Copy Location|Copy location' => 'Kopiér _placering|Kopiér adressen til den aktive side',
@@ -122,11 +123,12 @@ opretter navnerum for hver måned.
   'Could not delete page: {name}' => 'Siden "{name}" kunne ikke slettes',
   'Could not get annotated source for page {page}' => 'Det var ikke muligt at få en annoteret kilde for siden: {page}',
   'Could not get changes for page: {page}' => 'Det var ikke muligt at få ændringerne for siden: {page}',
+  'Could not get changes for this notebook' => '',
   'Could not get file for page: {page}' => 'Det var ikke muligt at få filen for siden: {page}',
   'Could not get versions to compare' => 'Det var ikke muligt at få versionerne til sammelinging',
   'Could not initialize version control' => 'Det var ikke muligt at starte versions kontrollen',
   'Could not load page: {name}' => 'Siden "{name}" kunne ikke indlæses',
-  'Could not rename {from} to {to}' => 'Det var ikke muligt at omdøbe fra "{from}" til "{to}"',
+  'Could not rename {from} to {to}' => 'Det var ikke muligt at omdøbe fra {from} til {to}',
   'Could not save page' => 'Siden kunne ikke gemmes',
   'Could not save version' => 'Det var ikke muligt at gennem versionen',
   'Creating a new link directly opens the page' => 'Oprettelse af en ny henvisning åbner automatisk den nye side',
@@ -153,15 +155,16 @@ opretter navnerum for hver måned.
   'Editing' => 'Redigering',
   'Email client' => 'Postprogram',
   'Enabled' => 'Aktivt',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => 'Aktivering af versions kontrol vil starte <b>Bazaar</b> versions kontrol systemet.
-Kig venligst under \'Hjælp\' for at læse om systemkravene og alternativer.',
   'Equation Editor' => 'Ligningsbehandler',
   'Equation Editor Log' => 'Ligningsbehandler log',
   'Expand side pane' => 'Udfold sidepanelet',
   'Export page' => 'Eksportér side',
   'Exporting page {number}' => 'Eksporterer side {number}',
+  'Failed to cleanup SVN working copy.' => '',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => '',
   'Failed to load plugin: {name}' => 'Udvidelsesmodulet "{name}" kunne ikke indlæses',
+  'Failed update working copy.' => 'Opdatering af arbejdskopi mislykkedes.',
   'File browser' => 'Filvælger',
   'File is not a text file: {file}' => 'Filen "{file}" er ikke en tekstfil',
   'Filter' => 'Filter',
@@ -190,6 +193,7 @@ Kig venligst under \'Hjælp\' for at læse om systemkravene og alternativer.',
   'Home Page' => 'Hjemmeside',
   'Icon' => 'Ikon',
   'Id' => 'Id',
+  'Include all open checkboxes' => '',
   'Index page' => 'Indeksside',
   'Initial version' => 'Første version',
   'Insert Date' => 'Indsæt dato',
@@ -209,6 +213,7 @@ Kig venligst under \'Hjælp\' for at læse om systemkravene og alternativer.',
   'New notebook' => 'Ny notesblok',
   'New page' => 'Ny side',
   'No such directory: {name}' => 'Mappen "{name}" findes ikke',
+  'No such file or directory: {name}' => 'Ikke sådan en fil eller mappe: {name}',
   'No such file: {file}' => 'Filen "{file}" kunne ikke findes',
   'No such notebook: {name}' => 'Notesbogen "{name}" findes ikke',
   'No such page: {page}' => 'Siden findes ikke: {page}',
@@ -234,6 +239,7 @@ bliver der også automatisk oprettet en ny side.',
   'Page Editable|Page editable' => 'Side redigerbar|Ændre på hvorvidt der er mulighed for at redigere siden',
   'Page name' => 'Sidenavn',
   'Pages' => 'Sider',
+  'Password' => 'Adgangskode',
   'Please enter a comment for this version' => 'Indtast en kommentar til denne version',
   'Please enter a name to save a copy of page: {page}' => 'Indtast venligst et navn for at gemme en kopi af siden: {page}',
   'Please enter a {app_type}' => 'Indtast venligst en {app_type}',
@@ -243,6 +249,9 @@ For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Angiv som minimum en mappe til at gemme dine sider i.
 Til en ny noteblok skal denne mappe være tom.
 For eksempel en mappe "Noter" i din hjemmemappe.',
+  'Please provide the password for
+{path}' => 'Angiv venligst adgangskoden for
+{path}',
   'Please select a notebook first' => 'Vælg venligst en notesblok først',
   'Please select a version first' => 'Angiv venligst en version først',
   'Plugin already loaded: {name}' => 'Udvidelsesmodulet "{name}" er allerede indlæst',
@@ -261,6 +270,9 @@ For eksempel en mappe "Noter" i din hjemmemappe.',
   'Rename to' => 'Omdøb til',
   'Replace _all' => 'Erstat _alt',
   'Replace with' => 'Erstat med',
+  'SVN cleanup|Cleanup SVN working copy' => '',
+  'SVN commit|Commit notebook to SVN repository' => '',
+  'SVN update|Update notebook from SVN repository' => '',
   'S_ave Version...|Save Version' => 'Ge_m version...|Gem version',
   'Save Copy' => 'Gem kopi',
   'Save version' => 'Gem version',
@@ -288,7 +300,7 @@ For eksempel en mappe "Noter" i din hjemmemappe.',
   'Text editor' => 'Tekstbehandler',
   'The equation failed to compile. Do you want to save anyway?' => 'Ligningen kunne ikke oversættes. Ønsker du at gemme alligevel?',
   'The equation for image: {path}
-is missing. Can not edit equation.' => 'Ligningen for billedet "{path}"
+is missing. Can not edit equation.' => 'Ligningen for billedet {path}
 mangler. Det er ikke muligt at redigere ligningen.',
   'This notebook does not have a document root' => 'Denne notesblok har ikke en dokumentrod',
   'This page does not exist
@@ -296,10 +308,14 @@ mangler. Det er ikke muligt at redigere ligningen.',
 404',
   'This page does not have a document folder' => 'Denne side indeholder ikke en dokumentmappe',
   'This page does not have a source' => 'Denne side har ikke nogen kildetekst',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => '',
   'To_day|Today' => '_I dag|Gå til i dags dato',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => '',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => '',
   'Underline' => 'Understreg',
   'Updating links' => 'Opdaterer henvisninger',
-  'Updating links in {name}' => 'Opdaterer henvisninger i "{name}"',
+  'Updating links in {name}' => 'Opdaterer henvisninger i {name}',
   'Updating..' => 'Opdaterer...',
   'Use "Backspace" to un-indent' => 'Brug tilbage-tasten til at fjerne indrykning',
   'Use "Ctrl-Space" to switch focus' => 'Brug Ctrl-Mellemrum for at skifte fokus',
@@ -321,6 +337,8 @@ mangler. Det er ikke muligt at redigere ligningen.',
   'Word Count' => 'Ordoptælling',
   'Words' => 'Ord',
   'You can add rules to your search query below' => 'Herunder kan du tilføje regler til din søgning',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => '',
   'You have no {app_type} configured' => 'Du har ikke nogen {app_type} konfigureret',
   'You need to restart the application
 for plugin changes to take effect.' => 'Du bliver nød til at genstarte programmet for at
@@ -342,6 +360,7 @@ for plugin changes to take effect.' => 'Du bliver nød til at genstarte programm
   '_Delete Page|Delete page' => '_Slet side|Slet den aktive side',
   '_Delete|Delete' => '_Slet|Slet tekst eller elementer',
   '_Discard changes' => 'For_kast ændringer',
+  '_Edit' => 'R_edigér',
   '_Edit Equation' => '_Redigér ligning',
   '_Edit Link' => '_Redigér henvisning',
   '_Edit Link...|Edit link' => '_Redigér henvisning...|Redigér en eksisterende henvisning',
