@@ -5,24 +5,27 @@
 # 
 # 
 # TRANSLATORS:
+# BBO (de)
+# Fabian Affolter (de)
 # Hokey (de)
 # Jaap Karssenberg (de)
 # Klaus Vormweg (de)
 # Matthias Mailänder (de)
 # Nikolaus Klumpp (de)
 # René 'Necoro' Neumann (de)
+# Vinzenz Vietzke (de)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-12 19:01+0000
-# Last-Translator: Klaus Vormweg <klaus.vormweg@gmx.de>
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2009-11-13 22:11+0000
+# Last-Translator: BBO <Unknown>
 # Language-Team: German <de@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2010-01-10 10:44+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -52,7 +55,7 @@ Wollen Sie sie einschalten?',
 The folder: {path}
 does not exist, do you want to create it now?' => '<b>Verzeichnis existiert nicht.</b>
 
-Das verzeichnis: {path}
+Das Verzeichnis: {path}
 gibt es noch nicht. Wollen Sie es anlegen?',
   '<b>Page already exists</b>
 
@@ -68,12 +71,12 @@ sie überschreiben?',
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '<b>Ältere Version wiederherstellen?</b>
+All changes since the last saved version will be lost !' => '<b>Seite durch eine ältere Version ersetzen!</b>
 
-Wollen Sie die Version {version}
-der Seite {page} wiederherstellen?
+Wollsen Sie die Seite: {page}
+durch die Version {version} ersetzen?
 
-Alle späteren Änderungen gehen verloren!',
+Alle Änderungen nach dieser Version gehen verloren!',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -92,7 +95,7 @@ Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
   'Add \'tearoff\' strips to the menus' => 'Menüs \'abreißbar\' machen',
   'Application show two text files side by side' => 'Programm, um zwei Textdateien nebeneinander darzustellen',
   'Application to compose email' => 'Mailprogramm',
-  'Application to edit text files' => 'Text Editor',
+  'Application to edit text files' => 'Anwendung zum Bearbeiten von Text-Dateien',
   'Application to open directories' => 'Dateibrowser',
   'Application to open urls' => 'Anwendung um URLs zu öffnen',
   'Attach _File|Attach external file' => 'Anhang hinzu_fügen|Eine externe Datei hinzufügen',
@@ -110,26 +113,32 @@ Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
   'Bold' => 'Fett',
   'Calen_dar|Show calendar' => '_Kalender|Öffne Kalenderfenster',
   'Calendar' => 'Kalender',
+  'Can not find application "bzr"' => 'Kann das Programm "bzr" nicht finden',
+  'Can not find application "{name}"' => 'Kann die Anwendung "{name}" nicht finden',
   'Can not save a version without comment' => 'Fassungen ohne Beschreibung können nicht gespeichert werden',
   'Can not save to page: {name}' => 'Kann Seite {name} nicht speichern',
-  'Can\'t find {url}' => 'Finde {url} nicht',
+  'Can\'t find {url}' => '{url} konnte nicht gefunden werden',
   'Cha_nge' => 'Ä_ndern',
   'Chars' => 'Zeichen',
   'Check _spelling|Spell check' => '_Rechtschreibprüfung|Rechtschreibprüfung',
-  'Choose {app_type}' => 'Wähle {app_type}',
+  'Check checkbox lists recursive' => 'Ankreuzlisten rekursiv ankreuzen',
+  'Checking a checkbox list item will also check any sub-items' => 'Ankreuzen eines Ankreuzfelds wird auch alle darunter liegenden Felder ankreuzen',
+  'Choose {app_type}' => '{app_type} wählen',
   'Co_mpare Page...' => '_Vergleiche Seite...',
   'Command' => 'Befehl',
+  'Comment' => 'Kommentar',
   'Compare this version with' => 'Diese Fassung vergleichen mit',
-  'Copy Email Address' => 'E-Mail Adresse kopieren',
+  'Copy Email Address' => 'E-Mail-Adresse kopieren',
   'Copy Location|Copy location' => 'Kopiere Seiten_adresse|Adresse der Wikiseite in die Zwischenablage kopieren',
-  'Copy _Link' => 'Kopiere _Link',
+  'Copy _Link' => '_Verknüpfung kopieren',
   'Could not delete page: {name}' => 'Konnte Seite {name} nicht löschen',
   'Could not get annotated source for page {page}' => 'Konnte den Quelltext mit Anmerkungen für die Seite {page} nicht laden',
   'Could not get changes for page: {page}' => 'Kann auf die Änderungen für die Seite "{page}" nicht zugreifen',
+  'Could not get changes for this notebook' => 'Konnte Änderungen für dieses Notizbuch nicht lesen',
   'Could not get file for page: {page}' => 'Kann auf die Datei für die Seite "{page}" nicht zugreifen',
   'Could not get versions to compare' => 'Kann auf die zu vergleichenden Fassungen nicht zugreifen',
-  'Could not initialize version control' => 'Kann die Versionskontrolle nicht initialisieren.',
-  'Could not load page: {name}' => 'Konnte Seite {name} nicht öffnen',
+  'Could not initialize version control' => 'Die Versionskontrolle konnte nicht initialisiert werden.',
+  'Could not load page: {name}' => 'Seite {name} konnte nicht öffnen werden',
   'Could not rename {from} to {to}' => 'Umbenennen von {from} nach {to} ist gescheitert',
   'Could not save page' => 'Speichern der Seite fehlgeschlagen',
   'Could not save version' => 'Konnte Fassung nicht speichern',
@@ -153,18 +162,21 @@ Wollen Sie Ihre Sammlung in das neue Layout umwandeln?
   'Edit Query' => 'Abfrage bearbeiten',
   'Edit _Source|Open source' => '_Quelltext bearbeiten|Quelltext der Seite mit externem Editor bearbeiten',
   'Edit notebook' => 'Editiere Notizbuch',
-  'Edit text files "wiki style"' => 'Bearbeite Textdateien im \'Wiki-Stil\'',
+  'Edit text files "wiki style"' => 'Textdateien im \'Wiki-Stil\' bearbeiten',
   'Editing' => 'Bearbeiten',
-  'Email client' => 'Mail Programm',
+  'Email client' => 'E-Mail-Programm',
   'Enabled' => 'Aktiviert',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => 'Das Einschalten der Versionskontrolle wird das <i><b>Bazaar</b> Version Control System</i> initialisieren. Klicken Sie \'Hilfe\', um die Systemanforderungen und mögliche Alternativen zu erfahren.',
   'Equation Editor' => 'Formel-Editor',
   'Equation Editor Log' => 'Formel-Editor Protokoll',
   'Expand side pane' => 'Seitenleiste erweitern',
   'Export page' => 'Exportiere Seite',
-  'Exporting page {number}' => 'Exportiere Seite {number}',
+  'Exporting page {number}' => 'Seite {number} exportieren',
+  'Failed to cleanup SVN working copy.' => 'Entsperren der Arbeitskopie fehlgeschlagen',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'SVN-Plugin konnte nicht geladen werden,
+haben Sie die Subversion-Werkzeuge installiert?',
   'Failed to load plugin: {name}' => 'Plugin {name} konnte nicht aktiviert werden',
+  'Failed update working copy.' => 'Erneuern der Arbeitskopie fehlgeschlagen',
   'File browser' => 'Dateibrowser',
   'File is not a text file: {file}' => 'Datei {file} ist keine Textdatei',
   'Filter' => 'Filter',
@@ -193,11 +205,12 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Home Page' => 'Startseite',
   'Icon' => 'Symbol',
   'Id' => 'Id',
+  'Include all open checkboxes' => 'Alle offenen Ankreuzfelder einschließen',
   'Index page' => 'Indexseite',
-  'Initial version' => 'Ausgangsfassung',
+  'Initial version' => 'Startversion',
   'Insert Date' => 'Datum einfügen',
   'Insert Image' => 'Bild einfügen',
-  'Insert Link' => 'Link einfügen',
+  'Insert Link' => 'Verknüpfung einfügen',
   'Insert from file' => 'Aus Datei einfügen',
   'Interface' => 'Erscheinungsbild',
   'Italic' => 'Kursiv',
@@ -212,8 +225,9 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'New notebook' => 'Neues Notizbuch',
   'New page' => 'Neue Seite anlegen',
   'No such directory: {name}' => 'Verzeichnis {name} existiert nicht',
+  'No such file or directory: {name}' => 'Datei oder Verzeichnis "{name}" nicht gefunden',
   'No such file: {file}' => 'Datei {file} existiert nicht',
-  'No such notebook: {name}' => 'Notizbuch {name} existiert nicht',
+  'No such notebook: {name}' => 'Notizbuch "{name}" existiert nicht',
   'No such page: {page}' => 'Seite existiert nicht: {page}',
   'No such plugin: {name}' => 'Plugin {name} existiert nicht',
   'Normal' => 'Standard',
@@ -228,8 +242,8 @@ neue, leere Seite erzeugt',
   'Notebooks' => 'Notizbücher',
   'Open Document _Folder|Open document folder' => 'Dokumentverzeichnis _öffnen|Dokumentverzeichnis öffnen',
   'Open Document _Root|Open document root' => '_Zim-Wurzelverzeichnis öffnen|Zim-Wurzelverzeichnis öffnen',
-  'Open _Directory' => 'Öffne _Verzeichnis',
-  'Open notebook' => 'Öffne Notizbuch',
+  'Open _Directory' => '_Verzeichnis öffnen',
+  'Open notebook' => 'Notizbuch öffnen',
   'Other...' => 'Andere…',
   'Output' => 'Ausgabe',
   'Output dir' => 'Ausgabeverzeichnis',
@@ -238,6 +252,7 @@ neue, leere Seite erzeugt',
   'Page Editable|Page editable' => 'Seite editierbar|Seite editierbar',
   'Page name' => 'Seitenname',
   'Pages' => 'Seiten',
+  'Password' => 'Passwort',
   'Please enter a comment for this version' => 'Bitte geben Sie eine Beschreibung für diese Fassung ein',
   'Please enter a name to save a copy of page: {page}' => 'Bitte geben Sie einen Namen ein, um eine Kopie der Seite {page} zu speichern.',
   'Please enter a {app_type}' => 'Bitte geben Sie ein: {app_type}',
@@ -247,6 +262,9 @@ For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Bitte mindestens ein Verzeichnis zum Abspeichern von Seiten angeben.
 Für ein neues Notizbuch sollte dies ein leeres Verzeichnis sein.
 Zum Beispiel ein Verzeichnis "Notizen" im Persönlichen Ordner.',
+  'Please provide the password for
+{path}' => 'Bitte geben Sie das Passwort für
+{path} ein',
   'Please select a notebook first' => 'Bitte wählen Sie zuerst ein Notizbuch aus',
   'Please select a version first' => 'Bitte zuerst eine Fassung wählen',
   'Plugin already loaded: {name}' => 'Plugin {name} ist schon aktiv',
@@ -265,14 +283,17 @@ Zum Beispiel ein Verzeichnis "Notizen" im Persönlichen Ordner.',
   'Rename to' => 'Umbenennen in',
   'Replace _all' => '_Alles ersetzen',
   'Replace with' => 'Ersetzen durch',
-  'S_ave Version...|Save Version' => 'Fassung S_peichern|Fassung Speichern',
-  'Save Copy' => 'Speichern unter',
+  'SVN cleanup|Cleanup SVN working copy' => 'SVN cleanup|SVN Arbeitskopie entsperren',
+  'SVN commit|Commit notebook to SVN repository' => 'SVN commit|Notizbuch ins SVN Archive einchecken',
+  'SVN update|Update notebook from SVN repository' => 'SVN update|Notizbuch aus dem SVN Archiv erneuern',
+  'S_ave Version...|Save Version' => 'Fassung s_peichern|Fassung speichern',
+  'Save Copy' => 'Kopie speichern',
   'Save version' => 'Fassung speichern',
   'Scanning tree ...' => 'Durchsuche Baum...',
   'Search' => 'Suche',
-  'Search _Backlinks...|Search Back links' => 'Suche nach _Backlinks...|Suche nach Backlinks...',
+  'Search _Backlinks...|Search Back links' => 'Suche nach _Backlinks ...|Suche nach Backlinks ...',
   'Select File' => 'Datei auswählen',
-  'Select Folder' => 'Ordner auswählen',
+  'Select Folder' => 'Verzeichnis auswählen',
   'Send To...' => 'Senden an …',
   'Show cursor for read-only' => 'Zeige Cursor bei schreibgeschützten Seiten',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Zeige den Cursor, auch wenn die Seite schreibgeschützt ist. Das ist nützlich, wenn Sie sich mit Hilfe der Tastatur durch die Seiten bewegen',
@@ -289,7 +310,7 @@ Zum Beispiel ein Verzeichnis "Notizen" im Persönlichen Ordner.',
   'Text' => 'Text',
   'Text Editor' => 'Texteditor',
   'Text _From File...|Insert text from file' => 'Text aus Datei ein_fügen...|Text aus einer Datei einfügen',
-  'Text editor' => 'Text Editor',
+  'Text editor' => 'Texteditor',
   'The equation failed to compile. Do you want to save anyway?' => 'Die Formel war fehlerhaft. Trotzdem speichern?',
   'The equation for image: {path}
 is missing. Can not edit equation.' => 'Die Formel für das Bild: {path}
@@ -301,7 +322,12 @@ bearbeitet werden.',
 404',
   'This page does not have a document folder' => 'Diese Seite gehört zu keinem Dokumentverzeichnis',
   'This page does not have a source' => 'Diese Seite hat keine Quelle',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => 'Diese Seite wurde im SVN Archiv geändert.
+Bitte erneuern sie Ihre Arbeitskopie (Werkzeuge -> SVN update).',
   'To_day|Today' => '_Heute|Erzeuge eine neue Seite für heute',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => 'Ankreuzfeld \'V\' umschalten|Ankreuzfeld umschalten',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => 'Ankreuzfeld \'X\' umschalten|Ankreuzfeld umschalten',
   'Underline' => 'Unterstrichen',
   'Updating links' => 'Links anpassen',
   'Updating links in {name}' => 'Passe Links in {name} an',
@@ -326,19 +352,22 @@ bearbeitet werden.',
   'Word Count' => 'Wortanzahl',
   'Words' => 'Worte',
   'You can add rules to your search query below' => 'Unten können Regeln zur Suchabfrage hinzugefügt werden',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => 'Sie können entweder das Versionskontrollsystem <b>Bazaar</b> oder <b>Subversion</b> verwenden.
+In der Hilfe finden Sie die Systemanforderungen.',
   'You have no {app_type} configured' => 'Es wurde kein {app_type} konfiguriert',
   'You need to restart the application
 for plugin changes to take effect.' => 'Sie müssen Zim neustarten, damit Änderungen
 der Plugin-Einstellungen wirksam werden',
   'Your name; this can be used in export templates' => 'Ihr Name (wird benutzt in Export-Templates)',
-  'Zim Desktop Wiki' => 'Zim Desktop Wiki',
+  'Zim Desktop Wiki' => 'Zim Desktop-Wiki',
   '_About|About' => '_Über|Über Zim',
   '_All' => '_Alle',
   '_Back|Go page back' => '_Zurück|Eine Seite zurück',
   '_Bold|Bold' => '_Fett|Fett',
-  '_Browse...' => '_Durchsuchen…',
+  '_Browse...' => '_Durchsuchen …',
   '_Bugs|Bugs' => '_Fehlermeldungen|Fehlermeldungen',
-  '_Child|Go to child page' => '_Untergeordnet|Gehe zur untergeordneten Seite',
+  '_Child|Go to child page' => '_Untergeordnet|Zur untergeordneten Seite gehen',
   '_Close|Close window' => '_Schließen|Fenster schließen',
   '_Contents|Help contents' => '_Inhalt|Inhalt der Hilfe',
   '_Copy Page...|Copy page' => '_Kopiere Seite...|Kopiere Seite',
@@ -347,12 +376,13 @@ der Plugin-Einstellungen wirksam werden',
   '_Delete Page|Delete page' => '_Löschen|Lösche Seite',
   '_Delete|Delete' => '_Löschen|Löschen',
   '_Discard changes' => 'Änderungen _verwerfen',
+  '_Edit' => 'B_earbeiten',
   '_Edit Equation' => 'Formel b_earbeiten',
-  '_Edit Link' => 'Bearbeite Link',
+  '_Edit Link' => 'Link _bearbeiten',
   '_Edit Link...|Edit link' => 'Link _bearbeiten|Link bearbeiten',
-  '_Edit|' => '_Bearbeiten|Bearbeiten',
+  '_Edit|' => '_Bearbeiten|',
   '_FAQ|FAQ' => '_FAQ|FAQ',
-  '_File|' => '_Datei|Datei',
+  '_File|' => '_Datei|',
   '_Filter' => '_Filter',
   '_Find...|Find' => '_Suchen|Suchen',
   '_Forward|Go page forward' => '_Vorwärts|Eine Seite vorwärts',
@@ -365,7 +395,7 @@ der Plugin-Einstellungen wirksam werden',
   '_Insert' => 'E_infügen',
   '_Insert|' => '_Einfügen|Einfügen',
   '_Italic|Italic' => '_Kursiv|Kursiv',
-  '_Jump To...|Jump to page' => 'S_pringe zu...|Springe zu Seite',
+  '_Jump To...|Jump to page' => 'S_pringe zu ...|Zu Seite springen',
   '_Keybindings|Key bindings' => '_Tastenkombinationen|Tastenkombinationen',
   '_Link' => '_Link',
   '_Link to date' => 'Ver_linke datum',
@@ -374,19 +404,19 @@ der Plugin-Einstellungen wirksam werden',
   '_Namespace|.' => '_Namensraum|Namensraum',
   '_New Page|New page' => '_Neue Seite|Neue Seite',
   '_Next' => '_Nächstes',
-  '_Next in index|Go to next page' => '_Nächste Seite im Index|Gehe zur nächsten Seite im Index',
+  '_Next in index|Go to next page' => '_Nächste Seite im Index|Zur nächsten Seite im Index gehen',
   '_Normal|Normal' => '_Normal|Normal',
-  '_Notebook Changes...' => 'Änderungsprotokoll _Notizbuch',
-  '_Open Another Notebook...|Open notebook' => 'Öffne ein weiteres N_otizbuch...|Öffne Notizbuch',
-  '_Open link' => 'Öffne _Link',
+  '_Notebook Changes...' => 'Änderungsprotokoll _Notizbuch ...',
+  '_Open Another Notebook...|Open notebook' => 'Ein weiteres N_otizbuch öffnen ...|Notizbuch öffnen',
+  '_Open link' => 'Verknüpfung öf_fnen',
   '_Overwrite' => '_Überschreiben',
   '_Page' => '_Seite',
   '_Page Changes...' => '_Änderungen an der Seite...',
-  '_Parent|Go to parent page' => '_Übergeordnet|Gehe zur übergeordneten Seite',
+  '_Parent|Go to parent page' => '_Übergeordnet|Zur übergeordneten Seite gehen',
   '_Paste|Paste' => '_Einfügen|Einfügen',
   '_Preview' => '_Vorschau',
   '_Previous' => '_Vorheriges',
-  '_Previous in index|Go to previous page' => '_Vorherige Seite im Index|Gehe zur vorherigen Seite im Index',
+  '_Previous in index|Go to previous page' => '_Vorherige Seite im Index|Zur vorherigen Seite im Index gehen',
   '_Properties' => '_Eigenschaften',
   '_Quit|Quit' => '_Beenden|Programm Beenden',
   '_Recent pages|.' => 'Kü_rzlich besuchte Seiten|Kürzlich besuchte Seiten',
@@ -398,17 +428,17 @@ der Plugin-Einstellungen wirksam werden',
   '_Replace...|Find and Replace' => '_Ersetzen|Suchen und Ersetzen',
   '_Reset' => '_Zurücksetzen',
   '_Restore Version...' => 'Ve_rsion wiederherstellen...',
-  '_Save Copy' => '_Speichern unter',
+  '_Save Copy' => '_Kopie speichern',
   '_Save a copy...' => '_Speichern unter',
   '_Save|Save page' => '_Speichern|Seite speichern',
   '_Screenshot...|Insert screenshot' => '_Bildschirmfoto|Bildschirmfoto einfügen',
   '_Search...|Search' => '_Suchen...|Suchen',
   '_Search|' => '_Suchen|Suchen',
   '_Send To...|Mail page' => '_Senden an...|Per E-Mail versenden',
-  '_Statusbar|Show statusbar' => '_Statuszeile|Schalte Statuszeile an oder ab',
+  '_Statusbar|Show statusbar' => '_Statuszeile|SStatuszeile an- oder abschalten',
   '_TODO List...|Open TODO List' => '_Aufgabenliste...|Öffne Aufgabenliste',
   '_Today' => '_Heute',
-  '_Toolbar|Show toolbar' => 'Werkzeugleis_te|Zeige Werkzeugleiste',
+  '_Toolbar|Show toolbar' => 'Werkzeugleis_te|Werkzeugleiste zeigen',
   '_Tools|' => '_Werkzeuge|Werkzeuge',
   '_Underline|Underline' => '_Unterstrichen|Unterstrichen',
   '_Undo|Undo' => '_Rückgängig|Rückgängig',
