@@ -9,15 +9,15 @@
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: pardus@cpan.org
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-13 11:29+0000
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2009-11-18 06:49+0000
 # Last-Translator: Juhana Uuttu <Unknown>
 # Language-Team: Finnish <fi@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:05+0000
+# X-Launchpad-Export-Date: 2010-01-10 10:44+0000
 # X-Generator: Launchpad (build Unknown)
 # X-Poedit-Country: FINLAND
 # X-Poedit-Language: Finnish
@@ -67,12 +67,12 @@ Haluatko kirjoittaa sen yli?',
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '<b>Palauta sivu tallennettuun versioon?</b>
+All changes since the last saved version will be lost !' => '<b>Palauta sivu tallennettuun versioon?</b>
 
 Haluatko palauttaa sivun: {page}
 versioon: {version} ?
 
-Kaikki tehdyt muutokset karsitaan pois!',
+Kaikki viime tallenuksesta lähtien tehdyt muutokset menetetään!',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -108,15 +108,20 @@ Haluatko päivittää muistivihkoosi käyttämään uutta pohjaa?
   'Bold' => 'Lihavoitus',
   'Calen_dar|Show calendar' => 'Kalenteri|Näytä kalenteri',
   'Calendar' => 'Kalenteri',
+  'Can not find application "bzr"' => 'En löydä ohjelmaa "bzr"',
+  'Can not find application "{name}"' => 'En löydä sovellusta "{name}"',
   'Can not save a version without comment' => 'En pysty tallentamaan versiota ilman kommenttia',
   'Can not save to page: {name}' => 'En pysty tallentamaan sivulle: {name}',
   'Can\'t find {url}' => 'En löydä {url}',
-  'Cha_nge' => '_Vaihda',
+  'Cha_nge' => 'M_uuta',
   'Chars' => 'Kirjaimia',
   'Check _spelling|Spell check' => 'Oikolue|Oikoluku',
+  'Check checkbox lists recursive' => 'Vaihda rastiruutulista rekursiivisesti',
+  'Checking a checkbox list item will also check any sub-items' => 'Rastiruudun muokkaus muuttaa myös sen alla olevat rastit',
   'Choose {app_type}' => 'Valitse {app_type}',
   'Co_mpare Page...' => 'Vertaa sivu...',
   'Command' => 'Komento',
+  'Comment' => 'Kommentti',
   'Compare this version with' => 'Vertaa tämä versio toiseen',
   'Copy Email Address' => 'Kopioi sähköpostiosoite',
   'Copy Location|Copy location' => 'Kopioi sijainti|Kopioi sijainti',
@@ -124,6 +129,7 @@ Haluatko päivittää muistivihkoosi käyttämään uutta pohjaa?
   'Could not delete page: {name}' => 'En pysty poistamaan sivua: {name}',
   'Could not get annotated source for page {page}' => 'En saanut lisähuomautettua lähdettä sivulle {page}',
   'Could not get changes for page: {page}' => 'En pysty hakemaan muutoksia sivulle: {page}',
+  'Could not get changes for this notebook' => 'En pysty hakemaan muutoksia tälle vihkolle',
   'Could not get file for page: {page}' => 'En saanut tiedostoa sivulle: {page}',
   'Could not get versions to compare' => 'En saanut versioita verrattaviksi',
   'Could not initialize version control' => 'En pysty käynnistämään versionhallintaa',
@@ -137,7 +143,7 @@ Haluatko päivittää muistivihkoosi käyttämään uutta pohjaa?
   'Current' => 'Nykyinen',
   'Customise' => 'Muokkaa',
   'Date' => 'Päivämäärä',
-  'Default notebook' => 'Vakiomuistivihko',
+  'Default notebook' => 'Vakiovihko',
   'Details' => 'Yksityiskohdat',
   'Diff Editor' => 'Diff-editori',
   'Diff editor' => 'Diff-editori',
@@ -155,15 +161,17 @@ Haluatko päivittää muistivihkoosi käyttämään uutta pohjaa?
   'Editing' => 'Muokkaus',
   'Email client' => 'Sähköposti-ohjelma',
   'Enabled' => 'Päällä',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => 'Versionhallinta hyödyntää <b>Bazaar</b>-versionhallintajärjestelmää.
-Paina \'Ohje\' lukeaksesi laitteistovaatimuksista ja vaihtoehdoista.',
   'Equation Editor' => 'Yhtälöeditori',
   'Equation Editor Log' => 'Yhtälöeditorin loki',
   'Expand side pane' => 'Avaa sivupaneeli',
   'Export page' => 'Vie sivu',
   'Exporting page {number}' => 'Viedään sivua {number}',
+  'Failed to cleanup SVN working copy.' => 'En onnistunut siivoamaan SVN-työkopiota.',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'SVN-lisäosan lataus epäonnistui.
+Onko sinulla subversion-työkalut asennettuna?',
   'Failed to load plugin: {name}' => 'Lisäosan lataus epäonnistui: {name}',
+  'Failed update working copy.' => 'Kopion päivitys epäonnistui.',
   'File browser' => 'Tiedostoselain',
   'File is not a text file: {file}' => 'Tiedosto ei sisällä tekstiä: {file}',
   'Filter' => 'Suodatin',
@@ -192,6 +200,7 @@ Paina \'Ohje\' lukeaksesi laitteistovaatimuksista ja vaihtoehdoista.',
   'Home Page' => 'Kotisivu',
   'Icon' => 'Ikoni',
   'Id' => 'Id',
+  'Include all open checkboxes' => 'Lisää mukaan kaikki avoimet valintaruudut',
   'Index page' => 'Indeksisivu',
   'Initial version' => 'Ensiversio',
   'Insert Date' => 'Lisää päivämäärä',
@@ -211,8 +220,9 @@ Paina \'Ohje\' lukeaksesi laitteistovaatimuksista ja vaihtoehdoista.',
   'New notebook' => 'Uusi muistivihko',
   'New page' => 'Uusi sivu',
   'No such directory: {name}' => 'Hakemisto ei olemassa: {name}',
+  'No such file or directory: {name}' => 'Tiedosto/hakemisto ei olemassa: {name}',
   'No such file: {file}' => 'Tiedosto ei olemassa: {file}',
-  'No such notebook: {name}' => 'Muistivihko ei olemassa: {name}',
+  'No such notebook: {name}' => 'Vihko ei olemassa: {name}',
   'No such page: {page}' => 'Sivu ei olemassa: {page}',
   'No such plugin: {name}' => 'Ei löytynyt lisäosaa: {name}',
   'Normal' => 'Normaali',
@@ -236,15 +246,19 @@ automaattisesti luo uuden sivun',
   'Page Editable|Page editable' => 'Sivu muokattavissa|Sivu muokattavissa',
   'Page name' => 'Sivun nimi',
   'Pages' => 'Sivut',
+  'Password' => 'Salasana',
   'Please enter a comment for this version' => 'Lisää kommentti versioon',
   'Please enter a name to save a copy of page: {page}' => 'Anna nimi tallentaaksesi kopion sivusta: {page}',
-  'Please enter a {app_type}' => 'Valite {app_type}',
+  'Please enter a {app_type}' => 'Valitse {app_type}',
   'Please give a page first' => 'Valitse sivu ensiksi',
   'Please give at least a directory to store your pages.
 For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Anna vähintään yksi hakemisto sivujen tallentamiseen.
 Uudelle muistivihkolle sen pitäisi olla tyhjä hakemisto.
 Esimerkiksi "Ruokareseptit"-kansio kotihakemistossasi.',
+  'Please provide the password for
+{path}' => 'Anna salasana hakemistolle:
+{path}',
   'Please select a notebook first' => 'Valitse muistivihko ensin',
   'Please select a version first' => 'Valitse versio ensiksi',
   'Plugin already loaded: {name}' => 'Lisäosa jo ladattu: {name}',
@@ -259,10 +273,13 @@ Esimerkiksi "Ruokareseptit"-kansio kotihakemistossasi.',
   'Rank' => 'Arvo',
   'Re-build Index|Rebuild index' => 'Uudista indeksi|Uudelleenrakenna indeksi',
   'Recursive' => 'Rekursiivinen',
-  'Rename page' => 'Uudelleennimeä sivu',
-  'Rename to' => 'Uudelleennimeä',
+  'Rename page' => 'Muuta sivun nimeä',
+  'Rename to' => 'Nimeä muotoon',
   'Replace _all' => 'Korvaa ka_ikki',
   'Replace with' => 'Korvaa',
+  'SVN cleanup|Cleanup SVN working copy' => 'SVN siivous|Siivoa SVN-työkopio',
+  'SVN commit|Commit notebook to SVN repository' => 'SVN-merkintä|Merkitse vihko SVN-varastoon',
+  'SVN update|Update notebook from SVN repository' => 'SVN-päivitys|Päivitä vihko SVN-varastosta',
   'S_ave Version...|Save Version' => 'Tallenna ve_rsio...|Tallenna versio',
   'Save Copy' => 'Tallenna kopio',
   'Save version' => 'Tallenna versio',
@@ -298,7 +315,12 @@ puuttuu. Ei voi muokata yhtälöä.',
 404',
   'This page does not have a document folder' => 'Tällä sivulla ei ole asiakirjakansiota',
   'This page does not have a source' => 'Tällä sivulla ei ole lähdettä',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => 'Tästä sivusta on päivitys varastossa.
+Ole hyvä ja päivitä kopiosi (Työkalut -> SVN päivitys).',
   'To_day|Today' => 'Tänään|Tänään',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => 'Vaihda rastiruutuun \'V\'|Vaihda rasti',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => 'Vaihda rastiruutuun \'X\'|Vaihda rasti',
   'Underline' => 'Alleviivaus',
   'Updating links' => 'Päivitetään linkit',
   'Updating links in {name}' => 'Päivitetään linkit kohteesta {name}',
@@ -316,13 +338,16 @@ puuttuu. Ei voi muokata yhtälöä.',
   'Verbatim' => 'Tasavälinen',
   'Versions' => 'Versiot',
   'View _Annotated...' => 'Katso lisä_huomautetut...',
-  'View _Log' => 'Katso _lokia',
+  'View _Log' => 'Näytä _loki',
   'Web browser' => 'Nettiselain',
   'Whole _word' => 'K_oko sana',
   'Width' => 'Laajuus',
   'Word Count' => 'Sanamäärä',
   'Words' => 'Sanoja',
   'You can add rules to your search query below' => 'Voit lisätä alapuolelle omia sääntöjä tiedusteluusi',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => 'Voit joko valita <b>Bazaar</b> tai <b>Subversion</b> versionhallintajärjestelmän.
+Valitse \'Ohje\' lukeaksesi järjestelmävaatimuksista.',
   'You have no {app_type} configured' => 'Sinulla ei ole {app_type} valittuna',
   'You need to restart the application
 for plugin changes to take effect.' => 'Sinun on käynnistettävä ohjelma
@@ -331,11 +356,11 @@ uudestaan että lisäosat vaikuttaisivat.',
   'Zim Desktop Wiki' => 'Zim työpöytä-wiki',
   '_About|About' => '_Tietoja|Tietoja',
   '_All' => 'K_aikki',
-  '_Back|Go page back' => '_Takaisin|Mene sivun takaisin',
+  '_Back|Go page back' => '_Takaisin|Mene sivun taakse',
   '_Bold|Bold' => 'Li_havoitus|Lihavoitus',
   '_Browse...' => '_Selaa',
   '_Bugs|Bugs' => '_Bugit|Bugit',
-  '_Child|Go to child page' => '_Jälkeläis|Mene sivun jälkeläiseen',
+  '_Child|Go to child page' => '_Ala|Mene alasivulle',
   '_Close|Close window' => '_Sulje|Sulje ikkuna',
   '_Contents|Help contents' => '_Sisältö|Ohjesisällöt',
   '_Copy Page...|Copy page' => '_Kopioi sivu...|Kopioi sivu',
@@ -344,11 +369,12 @@ uudestaan että lisäosat vaikuttaisivat.',
   '_Delete Page|Delete page' => '_Poista sivu|Poista sivu',
   '_Delete|Delete' => '_Poista|Poista',
   '_Discard changes' => '_Hylkää muutokset',
+  '_Edit' => '_Muokkaa',
   '_Edit Equation' => '_Muokkaa yhtälöä',
   '_Edit Link' => '_Muokkaa linkkiä',
   '_Edit Link...|Edit link' => '_Muokkaa linkki...|Muokkaa linkkiä',
   '_Edit|' => '_Muokkaa|',
-  '_FAQ|FAQ' => '_UKK|UKK',
+  '_FAQ|FAQ' => '_UKK|Usein Kysytyt Kysymykset',
   '_File|' => '_Tiedosto|',
   '_Filter' => '_Suodata',
   '_Find...|Find' => 'Etsi _sivusta...|Etsi sivusta',
@@ -379,7 +405,7 @@ uudestaan että lisäosat vaikuttaisivat.',
   '_Overwrite' => '_Ylikirjoita',
   '_Page' => '_Sivu',
   '_Page Changes...' => 'Sivumuutokset...',
-  '_Parent|Go to parent page' => '_Pää|Mene pääsivulle',
+  '_Parent|Go to parent page' => '_Ylä|Mene yläsivulle',
   '_Paste|Paste' => '_Liitä|Liitä',
   '_Preview' => '_Esikatsele',
   '_Previous' => 'E_dellinen',
