@@ -7,18 +7,19 @@
 # 
 # TRANSLATORS:
 # Mikael Mildén (sv)
+# nairobie (sv)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: 
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2007-11-22 17:18+0000
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2009-11-13 22:09+0000
 # Last-Translator: Mikael Mildén <Unknown>
 # Language-Team: Swedish
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=2; plural=n != 1;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2010-01-10 10:44+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -51,7 +52,7 @@ Do you want to overwrite it?' => '',
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '',
+All changes since the last saved version will be lost !' => '',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -81,15 +82,20 @@ Do you want to upgrade this notebook to the new layout?
   'Bold' => 'Fet',
   'Calen_dar|Show calendar' => '_Kalender|Visa kalender',
   'Calendar' => 'Kalender',
+  'Can not find application "bzr"' => '',
+  'Can not find application "{name}"' => '',
   'Can not save a version without comment' => '',
   'Can not save to page: {name}' => 'Kunde inte spara sida: {name}',
   'Can\'t find {url}' => 'Kan inte hitta {url}',
   'Cha_nge' => '_Ändra',
   'Chars' => 'Tecken',
   'Check _spelling|Spell check' => '_Stavningskontroll|Kontrollera stavning',
+  'Check checkbox lists recursive' => '',
+  'Checking a checkbox list item will also check any sub-items' => '',
   'Choose {app_type}' => 'Välj {app_type}',
   'Co_mpare Page...' => '',
   'Command' => 'Kommando',
+  'Comment' => '',
   'Compare this version with' => '',
   'Copy Email Address' => 'Kopiera e-postadress',
   'Copy Location|Copy location' => 'Kopiera _plats|Kopiera sidans adress',
@@ -97,6 +103,7 @@ Do you want to upgrade this notebook to the new layout?
   'Could not delete page: {name}' => 'Kunde inte ta bort sidan: {name}',
   'Could not get annotated source for page {page}' => '',
   'Could not get changes for page: {page}' => '',
+  'Could not get changes for this notebook' => '',
   'Could not get file for page: {page}' => '',
   'Could not get versions to compare' => '',
   'Could not initialize version control' => '',
@@ -128,14 +135,16 @@ Do you want to upgrade this notebook to the new layout?
   'Editing' => 'Redigering',
   'Email client' => 'E-postprogram',
   'Enabled' => 'Aktiverad',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => '',
   'Equation Editor' => 'Redigera formel',
   'Equation Editor Log' => 'Formelredigering: logg',
   'Expand side pane' => 'Visa hela trädet',
   'Export page' => 'Exportera sida',
   'Exporting page {number}' => 'Exporterar sida: {number}',
+  'Failed to cleanup SVN working copy.' => '',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => '',
   'Failed to load plugin: {name}' => 'Misslyckades med att ladda insticksmodul: {name}',
+  'Failed update working copy.' => '',
   'File browser' => 'Filbläddrare',
   'File is not a text file: {file}' => 'Filen är inte en textfil: {file}',
   'Filter' => '',
@@ -164,6 +173,7 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Home Page' => 'Hemsida',
   'Icon' => 'Ikon',
   'Id' => '',
+  'Include all open checkboxes' => '',
   'Index page' => 'Indexsida',
   'Initial version' => '',
   'Insert Date' => 'Infoga datum',
@@ -183,6 +193,7 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'New notebook' => 'Ny anteckningsbok',
   'New page' => 'Skapa ny sida',
   'No such directory: {name}' => 'Kunde inte hitta katalogen: {name}',
+  'No such file or directory: {name}' => '',
   'No such file: {file}' => 'Det finns ingen sådan fil: {file}',
   'No such notebook: {name}' => 'Det finns ingen sådan anteckningsbok: {name}',
   'No such page: {page}' => '',
@@ -208,6 +219,7 @@ skapar du en ny sida',
   'Page Editable|Page editable' => '',
   'Page name' => 'Sidnamn',
   'Pages' => 'Sidor',
+  'Password' => '',
   'Please enter a comment for this version' => '',
   'Please enter a name to save a copy of page: {page}' => '',
   'Please enter a {app_type}' => 'Välj {app_type}',
@@ -215,6 +227,8 @@ skapar du en ny sida',
   'Please give at least a directory to store your pages.
 For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => '',
+  'Please provide the password for
+{path}' => '',
   'Please select a notebook first' => '',
   'Please select a version first' => '',
   'Plugin already loaded: {name}' => 'Insticksmodulen har redan laddats: {name}',
@@ -233,6 +247,9 @@ For example a "Notes" directory in your home dir.' => '',
   'Rename to' => 'Byt namn till',
   'Replace _all' => 'Ersätt _alla',
   'Replace with' => 'Ersätt med',
+  'SVN cleanup|Cleanup SVN working copy' => '',
+  'SVN commit|Commit notebook to SVN repository' => '',
+  'SVN update|Update notebook from SVN repository' => '',
   'S_ave Version...|Save Version' => '',
   'Save Copy' => 'Spara som',
   'Save version' => '',
@@ -266,7 +283,11 @@ is missing. Can not edit equation.' => '',
 404' => '',
   'This page does not have a document folder' => '',
   'This page does not have a source' => 'Den här sidan har ingen källa',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => '',
   'To_day|Today' => 'Dagens datum|Infoga dagens datum',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => '',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => '',
   'Underline' => 'Understruken',
   'Updating links' => 'Uppdaterar länkar',
   'Updating links in {name}' => 'Uppdaterar länkar i {name}',
@@ -291,6 +312,8 @@ is missing. Can not edit equation.' => '',
   'Word Count' => 'Räkna ord',
   'Words' => 'Ord',
   'You can add rules to your search query below' => '',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => '',
   'You have no {app_type} configured' => 'Du måste konfigurera: {app_type}',
   'You need to restart the application
 for plugin changes to take effect.' => 'Du måste starta om programmet
@@ -312,6 +335,7 @@ för att insticksmodulerna ska börja fungera.',
   '_Delete Page|Delete page' => '_Ta bort|Ta bort den aktiva sidan',
   '_Delete|Delete' => '_Ta bort|Ta bort',
   '_Discard changes' => 'Spara _inte',
+  '_Edit' => '',
   '_Edit Equation' => 'Redigera _formel',
   '_Edit Link' => '_Redigera länk',
   '_Edit Link...|Edit link' => '_Redigera länk...|Redigera länk',
