@@ -5,19 +5,20 @@
 # 
 # 
 # TRANSLATORS:
+# Gökdeniz Karadağ (tr)
 # M. Emin Akşehirli (tr)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-13 20:29+0000
-# Last-Translator: M. Emin Akşehirli <m.emin@aksehirli.name.tr>
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2009-11-18 08:05+0000
+# Last-Translator: Gökdeniz Karadağ <Unknown>
 # Language-Team: Turkish <tr@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=1; plural=0;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2010-01-10 10:44+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -63,12 +64,12 @@ adlı sayfa zaten var.
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '<b>Sayfa kayıtlı sürüme geri döndürülsün mü?</b>
+All changes since the last saved version will be lost !' => '<b>Sayfa kayıtlı sürüme geri döndürülsün mü?</b>
 
-{page} adlı sayfayı {version} sürümüne
-geri döndürmek istiyor musunuz?
+{page} sayfasını,
+{version} sürümüne geri döndürmek istiyor musunuz?
 
-Bu sürümden sonra yapılan değişiklikler kaybolacak !',
+Kayıtlı son sürümden sonra yapılan tüm değişiklikler kaybolacak !',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -105,15 +106,20 @@ Bu not defterini yeni biçime yükseltmek ister misiniz?
   'Bold' => 'Kalın',
   'Calen_dar|Show calendar' => 'Tak_vim|Takvimi göster',
   'Calendar' => 'Takvim',
+  'Can not find application "bzr"' => '"bzr" uygulaması bulunamıyor',
+  'Can not find application "{name}"' => '"{name}" adlı uygulama bulunamıyor.',
   'Can not save a version without comment' => 'Açıklama olmadan sürüm kaydedilemiyor.',
   'Can not save to page: {name}' => '{name} adlı sayfa kaydedilemiyor.',
   'Can\'t find {url}' => '{url} bulunamıyor.',
   'Cha_nge' => '_Değiştir',
   'Chars' => 'Harf',
   'Check _spelling|Spell check' => 'Yazımı De_netle|Yazım denetimi',
+  'Check checkbox lists recursive' => 'Onay listeleri yinelemeli onaylansın',
+  'Checking a checkbox list item will also check any sub-items' => 'Onay listesinde bir onay öğesini işaretlemek bütün alt öğelerini de işaretler',
   'Choose {app_type}' => '{app_type} seçin',
   'Co_mpare Page...' => 'Sayfayı Karşı_laştır...',
   'Command' => 'Komut',
+  'Comment' => 'Açıklama',
   'Compare this version with' => 'Bu sürümü şununla karşılaştır:',
   'Copy Email Address' => 'E-posta Adresini Kopyala',
   'Copy Location|Copy location' => 'Konumu Kopyala|Konumu kopyala',
@@ -121,6 +127,7 @@ Bu not defterini yeni biçime yükseltmek ister misiniz?
   'Could not delete page: {name}' => '{name} adlı sayfa silinemiyor',
   'Could not get annotated source for page {page}' => 'Could not get annotated source for page {page}',
   'Could not get changes for page: {page}' => '{page} sayfası için değişiklikler alınamadı',
+  'Could not get changes for this notebook' => 'Bu not defteri için değişiklikler geri alınamıyor',
   'Could not get file for page: {page}' => '{page} sayfası için dosya alınamadı',
   'Could not get versions to compare' => 'Karşılaştırma için sürüm alınamadı',
   'Could not initialize version control' => 'Sürüm denetimi başlatılamadı.',
@@ -131,7 +138,7 @@ Bu not defterini yeni biçime yükseltmek ister misiniz?
   'Creating a new link directly opens the page' => 'Yeni bir bağlantı yaratmak direk olarak sayfayı açar',
   'Creation Date' => 'Oluşturulma Tarihi',
   'Cu_t|Cut' => 'K_es|Kes',
-  'Current' => 'Güncel',
+  'Current' => 'Şimdiki',
   'Customise' => 'Özelleştir',
   'Date' => 'Tarih',
   'Default notebook' => 'Öntanımlı not defteri',
@@ -152,15 +159,17 @@ Bu not defterini yeni biçime yükseltmek ister misiniz?
   'Editing' => 'Düzenleme',
   'Email client' => 'E-posta istemcisi',
   'Enabled' => 'Etkin',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => 'Sürüm denetimi, <b>Bazaar</b> Sürüm Denetim Sistemi\'ni kullanarak çalışır.
-Sistem gereksinimleri ve alternatifleri için lütfen \'yardım\'a tıklayın.',
   'Equation Editor' => 'Denklem Düzenleyici',
   'Equation Editor Log' => 'Denklem Düzenleyici Kayıtları',
   'Expand side pane' => 'Yan paneli genişlet',
   'Export page' => 'Sayfayı dışa aktar',
   'Exporting page {number}' => '{number} numaralı sayfa dışa aktarılıyor',
+  'Failed to cleanup SVN working copy.' => 'Çalışılan SVN kopyası toparlanamadı.',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => 'SVN eklentisi yüklenemedi.
+Subversion araçları kurulu mu?',
   'Failed to load plugin: {name}' => '{name} adlı eklenti yüklenemedi',
+  'Failed update working copy.' => 'Çalışan kopya güncellenemedi.',
   'File browser' => 'Dosya Tarayıcı',
   'File is not a text file: {file}' => '{file} dosyası bir metin dosyası değilBaşlık1',
   'Filter' => 'Süzgeç',
@@ -189,6 +198,7 @@ Sistem gereksinimleri ve alternatifleri için lütfen \'yardım\'a tıklayın.',
   'Home Page' => 'Başlangıç Sayfası',
   'Icon' => 'Simge',
   'Id' => 'ID',
+  'Include all open checkboxes' => 'İşaretlenmemiş bütün onay kutularını dahil et',
   'Index page' => 'Index sayfası',
   'Initial version' => 'İlk sürüm',
   'Insert Date' => 'Tarih Ekle',
@@ -208,6 +218,7 @@ Sistem gereksinimleri ve alternatifleri için lütfen \'yardım\'a tıklayın.',
   'New notebook' => 'Yeni not defteri',
   'New page' => 'Yeni sayfa',
   'No such directory: {name}' => '{name} adlı bir dizin yok.',
+  'No such file or directory: {name}' => '{name} adında bir dosya ya da dizin yok.',
   'No such file: {file}' => '{file} dosyası bulunamadı',
   'No such notebook: {name}' => '{name} adlı bir not defteri yok.',
   'No such page: {page}' => '{page} adlı bir sayfa yok',
@@ -233,6 +244,7 @@ yeni bir sayfa oluşturabilirsiniz.',
   'Page Editable|Page editable' => 'Sayfa Düzenlenebilir|Sayfa düzenlenebilir',
   'Page name' => 'Sayfa adı',
   'Pages' => 'Sayfalar',
+  'Password' => 'Parola',
   'Please enter a comment for this version' => 'Bu sürüm için bir açıklama girin',
   'Please enter a name to save a copy of page: {page}' => '{page} adlı sayfanın kopyası için isim girin:',
   'Please enter a {app_type}' => 'Lütfen bir {app_type} seçin',
@@ -242,11 +254,14 @@ For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Sayfaların saklanacağı dizini belirtin.
 Yeni bir not defteri için boş bir dizin belirtmelisiniz.
 Örneğin bağlangıç dizininizdeki "Notlar" dizini olabilir.',
+  'Please provide the password for
+{path}' => '{path} 
+için bir parola girin.',
   'Please select a notebook first' => 'Lütfen öncelikle bir not defteri seçin',
   'Please select a version first' => 'Öncelikle bir sürüm seçin',
   'Plugin already loaded: {name}' => '{name} adlı eklenti zaten yüklü.',
   'Plugins' => 'Eklentiler',
-  'Pr_eferences|Preferences dialog' => 'Y_eğlenenler|Yeğlenen ayarlar',
+  'Pr_eferences|Preferences dialog' => 'T_ercihler|Tercihleri düzenle',
   'Preferences' => 'Yeğlenenler',
   'Prefix document root' => 'Belge kök dizini ön eki',
   'Print to Browser|Print to browser' => 'Web Gezginine Gönder|Sayfanın Web gezgininde nasıl görüneceğine bakın',
@@ -260,6 +275,9 @@ Yeni bir not defteri için boş bir dizin belirtmelisiniz.
   'Rename to' => 'Yeni ad:',
   'Replace _all' => '_Tümünü değiştir',
   'Replace with' => 'Yerine bunu koy:',
+  'SVN cleanup|Cleanup SVN working copy' => 'SVN toparla|(cleanup)Çalışılan SVN kopyasını toparlar, temizler',
+  'SVN commit|Commit notebook to SVN repository' => 'SVN\'ye işle|(commit)Not defterini SVN deposuna işle',
+  'SVN update|Update notebook from SVN repository' => 'SVN\'den güncelle|(update)Not defterini SVN deposundan günceller',
   'S_ave Version...|Save Version' => 'Sü_rümü Kaydet...|Sürümü Kaydet',
   'Save Copy' => 'Kopyayı Kaydet',
   'Save version' => 'Sürümü kaydet',
@@ -295,7 +313,12 @@ bulunamadı. Denklem düzenlenemez.',
 404',
   'This page does not have a document folder' => 'Bu sayfanın bir belge dizini yok',
   'This page does not have a source' => 'Bu sayfanın kaynak kodu yok',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => 'Depodaki sayfa güncellenmiş.
+Lütfen çalıştığınız kopyayı güncelleyin (Tools -> SVN\'den güncelle).',
   'To_day|Today' => 'Bu_gün|Bugün',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => 'Onay Kutusunu \'V\'le | Onay kutusunu değiştir',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => 'Onay Kutusunu \'X\'le | Onay kutusunu değiştir',
   'Underline' => 'Altı çizili',
   'Updating links' => 'Bağlantılar güncelleniyor',
   'Updating links in {name}' => '{name} içindeki bağlantılar güncelleniyor',
@@ -320,6 +343,9 @@ bulunamadı. Denklem düzenlenemez.',
   'Word Count' => 'Sözcük Sayımı',
   'Words' => 'Sözcük',
   'You can add rules to your search query below' => 'Aşağıdan, arama sorgunuza yeni kurallar ekleyebilirsiniz',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => '<b>Bazaar</b> ya da <b>Subversion</b> Sürüm Denetim Sistemleri\'nden birini seçebilirsiniz.
+Sistem isterleri hakkında bilgi almak için lütfen \'yardım\'a tıklayın.',
   'You have no {app_type} configured' => 'Ayarlanmış bir {app_type} yok.',
   'You need to restart the application
 for plugin changes to take effect.' => 'Eklentilerin etkin olabilmesi için
@@ -341,6 +367,7 @@ uygulamayı yeniden başlatmalısınız.',
   '_Delete Page|Delete page' => 'Sayfayı _Sil|Sayfayı Sil',
   '_Delete|Delete' => 'S_il|Sil',
   '_Discard changes' => '_Değişiklikleri sil',
+  '_Edit' => '_Düzenle',
   '_Edit Equation' => 'Denklemi D_üzenle',
   '_Edit Link' => 'Bağlantıyı _Düzenle',
   '_Edit Link...|Edit link' => 'Bağlantıyı _Düzenle...|Bağlantıyı düzenle',
