@@ -5,20 +5,24 @@
 # 
 # 
 # TRANSLATORS:
-# rainofchaos (zh_CN)
+# Aron Xu (zh_CN)
+# Cheese Lee (zh_CN)
+# Junnan Wu (zh_CN)
+# forget (zh_CN)
+# 冯超 (zh_CN)
 # 太和 (zh_CN)
 # 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-08-06 00:10+0200
-# PO-Revision-Date: 2008-08-16 07:32+0000
-# Last-Translator: rainofchaos <rainofchaos@gmail.com>
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2009-11-18 01:32+0000
+# Last-Translator: forget <Unknown>
 # Language-Team: Simplified Chinese <zh_CN@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
 # Plural-Forms: nplurals=1; plural=0;
-# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Launchpad-Export-Date: 2010-01-10 10:44+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
@@ -63,12 +67,12 @@ Do you want to overwrite it?' => '<b>页面已经存在</b>
 Do you want to restore page: {page}
 to saved version: {version} ?
 
-All changes since this version will be lost !' => '<b>将页面恢复到保存的版本？</b>
+All changes since the last saved version will be lost !' => '<b>要回复到已保存的版本吗？</b>
 
-确定恢复页面: {page}
-到保存的版本: {version} ?
+要将页:{page}
+回复到已保存版本:{version}吗？
 
-这个版本之后的修改都会丢失!',
+上次保存版本以后的改动将会被丢弃！',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -105,15 +109,20 @@ Do you want to upgrade this notebook to the new layout?
   'Bold' => '粗体',
   'Calen_dar|Show calendar' => '日历(_D)|显示日历',
   'Calendar' => '日历',
+  'Can not find application "bzr"' => '没有找到应用程序"bzr"',
+  'Can not find application "{name}"' => '没有找到应用程序"{name}"',
   'Can not save a version without comment' => '无法保存没有注释的版本',
   'Can not save to page: {name}' => '无法保存到页面: {name}',
   'Can\'t find {url}' => '无法找到 {url}',
   'Cha_nge' => '更改(_N)',
   'Chars' => '字符',
   'Check _spelling|Spell check' => '拼写检查(_S)|拼写检查',
+  'Check checkbox lists recursive' => '递归选中复选框序列',
+  'Checking a checkbox list item will also check any sub-items' => '选中一个复选框时自动选中其子项',
   'Choose {app_type}' => '选择 {app_type}',
   'Co_mpare Page...' => '对比页面(_M)...',
   'Command' => '命令',
+  'Comment' => '备注',
   'Compare this version with' => '对比版本：',
   'Copy Email Address' => '复制电子邮件地址',
   'Copy Location|Copy location' => '复制地址|复制地址',
@@ -121,6 +130,7 @@ Do you want to upgrade this notebook to the new layout?
   'Could not delete page: {name}' => '无法删除页面: {name}',
   'Could not get annotated source for page {page}' => '无法找到页面 {page} 的注释源',
   'Could not get changes for page: {page}' => '无法找到页面 {page} 的修改',
+  'Could not get changes for this notebook' => '无法获得此笔记本的改动',
   'Could not get file for page: {page}' => '无法找到页面 {page} 的文件',
   'Could not get versions to compare' => '无法找到对比版本',
   'Could not initialize version control' => '无法初始化版本控制',
@@ -152,15 +162,16 @@ Do you want to upgrade this notebook to the new layout?
   'Editing' => '编辑',
   'Email client' => '邮件客户端',
   'Enabled' => '已启用',
-  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
-Please click \'help\' to read about the system requirements and alternatives.' => '启用版本控制将会初始化 <b>Bazaar</b> 版本控制系统。
-点击"帮助" 获取系统要求和其他选择。',
   'Equation Editor' => '公式编辑器',
   'Equation Editor Log' => '公式编辑器日志',
   'Expand side pane' => '扩展侧边栏',
   'Export page' => '导出页面',
   'Exporting page {number}' => '导出页面 {number}',
+  'Failed to cleanup SVN working copy.' => '清除临时文件失败',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => '无法加载SVN插件，确认安装subversion工具了吗？',
   'Failed to load plugin: {name}' => '没有加载成功的插件:{name}',
+  'Failed update working copy.' => '清除临时文件失败',
   'File browser' => '文件浏览器',
   'File is not a text file: {file}' => '不是文本文件: {file}',
   'Filter' => '过滤器',
@@ -172,7 +183,7 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Follow new link' => '进入新链接',
   'For_mat|' => '格式(_M)|',
   'Format' => '格式',
-  'General' => '基本',
+  'General' => '常规',
   'Go to "{link}"' => '跳转到 "{link}"',
   'H_idden|.' => '隐藏(_H)|',
   'Head _1|Heading 1' => '标题 1( _1)|标题 1',
@@ -189,6 +200,7 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'Home Page' => '主页',
   'Icon' => '图标',
   'Id' => '编号',
+  'Include all open checkboxes' => '加入所有打开的复选框',
   'Index page' => '索引页',
   'Initial version' => '初始版本',
   'Insert Date' => '插入日期',
@@ -208,6 +220,7 @@ Please click \'help\' to read about the system requirements and alternatives.' =
   'New notebook' => '新建记事本',
   'New page' => '新页面',
   'No such directory: {name}' => '没有这个目录：{name}',
+  'No such file or directory: {name}' => '没有这个文件或目录：{name}',
   'No such file: {file}' => '无此文件:{file}',
   'No such notebook: {name}' => '没有这个笔记本：{name}',
   'No such page: {page}' => '无此页:{page}',
@@ -233,6 +246,7 @@ also automatically creates a new page.' => '注意，如果链接到不存在的
   'Page Editable|Page editable' => '页面可编辑|页面可编辑',
   'Page name' => '页面名称',
   'Pages' => '页面',
+  'Password' => '密码',
   'Please enter a comment for this version' => '请为此版本添加一个注释',
   'Please enter a name to save a copy of page: {page}' => '请输入页面 {page} 的副本名称:',
   'Please enter a {app_type}' => '请输入一个 {app_type}',
@@ -242,6 +256,8 @@ For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => '请至少为您的页面提供一个目录。
 对于新的记事本来说应该是空目录。
 例如在您的主目录中的 "记事本"目录。',
+  'Please provide the password for
+{path}' => '请输入{path}的密码',
   'Please select a notebook first' => '请先选择一个记事本',
   'Please select a version first' => '请先选择一个版本',
   'Plugin already loaded: {name}' => '已经加载的插件:{name}',
@@ -260,6 +276,9 @@ For example a "Notes" directory in your home dir.' => '请至少为您的页面
   'Rename to' => '重命名为',
   'Replace _all' => '全部替换(_A)',
   'Replace with' => '替换为',
+  'SVN cleanup|Cleanup SVN working copy' => '清除SVN临时文件',
+  'SVN commit|Commit notebook to SVN repository' => '读取SVN库',
+  'SVN update|Update notebook from SVN repository' => 'SVN 更新|从SVN库更新笔记本',
   'S_ave Version...|Save Version' => '保存版本(_A)...|保存版本',
   'Save Copy' => '保存副本',
   'Save version' => '保存版本',
@@ -295,7 +314,11 @@ is missing. Can not edit equation.' => '无法找到图像: {path}
 404',
   'This page does not have a document folder' => '此页面无文档文件夹',
   'This page does not have a source' => '此页面没有源代码',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => '请对文件进行更新（工具>更新SVN）',
   'To_day|Today' => '今天(_D)|今天',
+  'Toggle Chechbox \'V\'|Toggle checkbox' => '选中复选框 \'V\'|切换复选框',
+  'Toggle Chechbox \'X\'|Toggle checkbox' => '选中复选框 \'X\'|切换复选框',
   'Underline' => '下划线',
   'Updating links' => '更新链接',
   'Updating links in {name}' => '更新{name}中的链接',
@@ -320,6 +343,9 @@ is missing. Can not edit equation.' => '无法找到图像: {path}
   'Word Count' => '字数统计',
   'Words' => '字',
   'You can add rules to your search query below' => '可以为查询添加规则',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => '你可以选择使用<b>Bazaar</b>或者<b>Subversion</b>版本控制系统
+请点击“帮助”以了解系统要求',
   'You have no {app_type} configured' => '您没有配置 {app_type}',
   'You need to restart the application
 for plugin changes to take effect.' => '重启应用程序后
@@ -341,6 +367,7 @@ for plugin changes to take effect.' => '重启应用程序后
   '_Delete Page|Delete page' => '删除页面(_D)|删除页面',
   '_Delete|Delete' => '删除(_D)|删除',
   '_Discard changes' => '放弃更改(_D)',
+  '_Edit' => '编辑(_E)',
   '_Edit Equation' => '编辑公式(_E)',
   '_Edit Link' => '编辑链接(_E)',
   '_Edit Link...|Edit link' => '编辑链接(_E)|编辑链接',
