@@ -12,11 +12,15 @@ return 1 if  ! $$conf{icon_per_notebook}
 
 # We are note running using a daemon or the user want an individual
 # icon for each notebook. Initialize icon object.
-eval 'use Zim::GUI::TrayIcon';
+eval { 
+	Gtk2->CHECK_VERSION(2, 10, 0)
+		or require Gtk2::TrayIcon;
+	require Zim::GUI::TrayIcon;
+};
 if ($@) {
 	$app->error_dialog(
 		"Failed to load TrayIcon plugin.\n".
-		"You either need gtk+ >= 2.10 or you".
+		"You either need gtk+ >= 2.10 or you\n".
 		"need to have Gtk2::TrayIcon installed.", $@);
 	$app->unplug('TrayIcon');
 	return 1;
